@@ -146,6 +146,9 @@ impl<'a, AUTHENTICATIONCODETYPE: TDAuthenticationCodeType> TDAuthenticationCodeT
 impl<'a, AUTHORIZATIONSTATE: TDAuthorizationState> TDAuthorizationState for &'a AUTHORIZATIONSTATE {}
 impl<'a, AUTHORIZATIONSTATE: TDAuthorizationState> TDAuthorizationState for &'a mut AUTHORIZATIONSTATE {}
 
+impl<'a, BACKGROUNDFILL: TDBackgroundFill> TDBackgroundFill for &'a BACKGROUNDFILL {}
+impl<'a, BACKGROUNDFILL: TDBackgroundFill> TDBackgroundFill for &'a mut BACKGROUNDFILL {}
+
 impl<'a, BACKGROUNDTYPE: TDBackgroundType> TDBackgroundType for &'a BACKGROUNDTYPE {}
 impl<'a, BACKGROUNDTYPE: TDBackgroundType> TDBackgroundType for &'a mut BACKGROUNDTYPE {}
 
@@ -161,12 +164,21 @@ impl<'a, CALLSTATE: TDCallState> TDCallState for &'a mut CALLSTATE {}
 impl<'a, CALLBACKQUERYPAYLOAD: TDCallbackQueryPayload> TDCallbackQueryPayload for &'a CALLBACKQUERYPAYLOAD {}
 impl<'a, CALLBACKQUERYPAYLOAD: TDCallbackQueryPayload> TDCallbackQueryPayload for &'a mut CALLBACKQUERYPAYLOAD {}
 
+impl<'a, CANTRANSFEROWNERSHIPRESULT: TDCanTransferOwnershipResult> TDCanTransferOwnershipResult for &'a CANTRANSFEROWNERSHIPRESULT {}
+impl<'a, CANTRANSFEROWNERSHIPRESULT: TDCanTransferOwnershipResult> TDCanTransferOwnershipResult for &'a mut CANTRANSFEROWNERSHIPRESULT {}
+
 impl<'a, CHATACTION: TDChatAction> TDChatAction for &'a CHATACTION {}
 impl<'a, CHATACTION: TDChatAction> TDChatAction for &'a mut CHATACTION {}
 
+impl<'a, CHATACTIONBAR: TDChatActionBar> TDChatActionBar for &'a CHATACTIONBAR {}
+impl<'a, CHATACTIONBAR: TDChatActionBar> TDChatActionBar for &'a mut CHATACTIONBAR {}
+
 impl<'a, CHATEVENTACTION: TDChatEventAction> TDChatEventAction for &'a CHATEVENTACTION {}
 impl<'a, CHATEVENTACTION: TDChatEventAction> TDChatEventAction for &'a mut CHATEVENTACTION {}
 
+impl<'a, CHATLIST: TDChatList> TDChatList for &'a CHATLIST {}
+impl<'a, CHATLIST: TDChatList> TDChatList for &'a mut CHATLIST {}
+
 impl<'a, CHATMEMBERSTATUS: TDChatMemberStatus> TDChatMemberStatus for &'a CHATMEMBERSTATUS {}
 impl<'a, CHATMEMBERSTATUS: TDChatMemberStatus> TDChatMemberStatus for &'a mut CHATMEMBERSTATUS {}
 
@@ -227,12 +239,12 @@ impl<'a, KEYBOARDBUTTONTYPE: TDKeyboardButtonType> TDKeyboardButtonType for &'a
 impl<'a, LANGUAGEPACKSTRINGVALUE: TDLanguagePackStringValue> TDLanguagePackStringValue for &'a LANGUAGEPACKSTRINGVALUE {}
 impl<'a, LANGUAGEPACKSTRINGVALUE: TDLanguagePackStringValue> TDLanguagePackStringValue for &'a mut LANGUAGEPACKSTRINGVALUE {}
 
-impl<'a, LINKSTATE: TDLinkState> TDLinkState for &'a LINKSTATE {}
-impl<'a, LINKSTATE: TDLinkState> TDLinkState for &'a mut LINKSTATE {}
-
 impl<'a, LOGSTREAM: TDLogStream> TDLogStream for &'a LOGSTREAM {}
 impl<'a, LOGSTREAM: TDLogStream> TDLogStream for &'a mut LOGSTREAM {}
 
+impl<'a, LOGINURLINFO: TDLoginUrlInfo> TDLoginUrlInfo for &'a LOGINURLINFO {}
+impl<'a, LOGINURLINFO: TDLoginUrlInfo> TDLoginUrlInfo for &'a mut LOGINURLINFO {}
+
 impl<'a, MASKPOINT: TDMaskPoint> TDMaskPoint for &'a MASKPOINT {}
 impl<'a, MASKPOINT: TDMaskPoint> TDMaskPoint for &'a mut MASKPOINT {}
 
@@ -242,6 +254,9 @@ impl<'a, MESSAGECONTENT: TDMessageContent> TDMessageContent for &'a mut MESSAGEC
 impl<'a, MESSAGEFORWARDORIGIN: TDMessageForwardOrigin> TDMessageForwardOrigin for &'a MESSAGEFORWARDORIGIN {}
 impl<'a, MESSAGEFORWARDORIGIN: TDMessageForwardOrigin> TDMessageForwardOrigin for &'a mut MESSAGEFORWARDORIGIN {}
 
+impl<'a, MESSAGESCHEDULINGSTATE: TDMessageSchedulingState> TDMessageSchedulingState for &'a MESSAGESCHEDULINGSTATE {}
+impl<'a, MESSAGESCHEDULINGSTATE: TDMessageSchedulingState> TDMessageSchedulingState for &'a mut MESSAGESCHEDULINGSTATE {}
+
 impl<'a, MESSAGESENDINGSTATE: TDMessageSendingState> TDMessageSendingState for &'a MESSAGESENDINGSTATE {}
 impl<'a, MESSAGESENDINGSTATE: TDMessageSendingState> TDMessageSendingState for &'a mut MESSAGESENDINGSTATE {}
 
@@ -281,9 +296,15 @@ impl<'a, PASSPORTELEMENTERRORSOURCE: TDPassportElementErrorSource> TDPassportEle
 impl<'a, PASSPORTELEMENTTYPE: TDPassportElementType> TDPassportElementType for &'a PASSPORTELEMENTTYPE {}
 impl<'a, PASSPORTELEMENTTYPE: TDPassportElementType> TDPassportElementType for &'a mut PASSPORTELEMENTTYPE {}
 
+impl<'a, POLLTYPE: TDPollType> TDPollType for &'a POLLTYPE {}
+impl<'a, POLLTYPE: TDPollType> TDPollType for &'a mut POLLTYPE {}
+
 impl<'a, PROXYTYPE: TDProxyType> TDProxyType for &'a PROXYTYPE {}
 impl<'a, PROXYTYPE: TDProxyType> TDProxyType for &'a mut PROXYTYPE {}
 
+impl<'a, PUBLICCHATTYPE: TDPublicChatType> TDPublicChatType for &'a PUBLICCHATTYPE {}
+impl<'a, PUBLICCHATTYPE: TDPublicChatType> TDPublicChatType for &'a mut PUBLICCHATTYPE {}
+
 impl<'a, PUSHMESSAGECONTENT: TDPushMessageContent> TDPushMessageContent for &'a PUSHMESSAGECONTENT {}
 impl<'a, PUSHMESSAGECONTENT: TDPushMessageContent> TDPushMessageContent for &'a mut PUSHMESSAGECONTENT {}
 
@@ -338,8 +359,11 @@ pub enum TdType {
   UpdateBasicGroup(UpdateBasicGroup),
   UpdateBasicGroupFullInfo(UpdateBasicGroupFullInfo),
   UpdateCall(UpdateCall),
+  UpdateChatActionBar(UpdateChatActionBar),
+  UpdateChatChatList(UpdateChatChatList),
   UpdateChatDefaultDisableNotification(UpdateChatDefaultDisableNotification),
   UpdateChatDraftMessage(UpdateChatDraftMessage),
+  UpdateChatHasScheduledMessages(UpdateChatHasScheduledMessages),
   UpdateChatIsMarkedAsUnread(UpdateChatIsMarkedAsUnread),
   UpdateChatIsPinned(UpdateChatIsPinned),
   UpdateChatIsSponsored(UpdateChatIsSponsored),
@@ -367,6 +391,7 @@ pub enum TdType {
   UpdateMessageContent(UpdateMessageContent),
   UpdateMessageContentOpened(UpdateMessageContentOpened),
   UpdateMessageEdited(UpdateMessageEdited),
+  UpdateMessageLiveLocationViewed(UpdateMessageLiveLocationViewed),
   UpdateMessageMentionRead(UpdateMessageMentionRead),
   UpdateMessageSendAcknowledged(UpdateMessageSendAcknowledged),
   UpdateMessageSendFailed(UpdateMessageSendFailed),
@@ -386,6 +411,7 @@ pub enum TdType {
   UpdateNotificationGroup(UpdateNotificationGroup),
   UpdateOption(UpdateOption),
   UpdatePoll(UpdatePoll),
+  UpdatePollAnswer(UpdatePollAnswer),
   UpdateRecentStickers(UpdateRecentStickers),
   UpdateSavedAnimations(UpdateSavedAnimations),
   UpdateScopeNotificationSettings(UpdateScopeNotificationSettings),
@@ -403,12 +429,15 @@ pub enum TdType {
   UpdateUserFullInfo(UpdateUserFullInfo),
   UpdateUserPrivacySettingRules(UpdateUserPrivacySettingRules),
   UpdateUserStatus(UpdateUserStatus),
+  UpdateUsersNearby(UpdateUsersNearby),
 
   AuthorizationState(AuthorizationState),
+  CanTransferOwnershipResult(CanTransferOwnershipResult),
   CheckChatUsernameResult(CheckChatUsernameResult),
   JsonValue(JsonValue),
   LanguagePackStringValue(LanguagePackStringValue),
   LogStream(LogStream),
+  LoginUrlInfo(LoginUrlInfo),
   OptionValue(OptionValue),
   PassportElement(PassportElement),
   Update(Update),
@@ -423,13 +452,14 @@ pub enum TdType {
   CallId(CallId),
   CallbackQueryAnswer(CallbackQueryAnswer),
   Chat(Chat),
+  ChatAdministrators(ChatAdministrators),
   ChatEvents(ChatEvents),
   ChatInviteLink(ChatInviteLink),
   ChatInviteLinkInfo(ChatInviteLinkInfo),
   ChatMember(ChatMember),
   ChatMembers(ChatMembers),
-  ChatReportSpamState(ChatReportSpamState),
   Chats(Chats),
+  ChatsNearby(ChatsNearby),
   ConnectedWebsites(ConnectedWebsites),
   Count(Count),
   CustomRequestResult(CustomRequestResult),
@@ -473,6 +503,7 @@ pub enum TdType {
   ScopeNotificationSettings(ScopeNotificationSettings),
   Seconds(Seconds),
   SecretChat(SecretChat),
+  Session(Session),
   Sessions(Sessions),
   StickerSet(StickerSet),
   StickerSets(StickerSets),
@@ -514,8 +545,11 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (updateBasicGroup, UpdateBasicGroup);
   (updateBasicGroupFullInfo, UpdateBasicGroupFullInfo);
   (updateCall, UpdateCall);
+  (updateChatActionBar, UpdateChatActionBar);
+  (updateChatChatList, UpdateChatChatList);
   (updateChatDefaultDisableNotification, UpdateChatDefaultDisableNotification);
   (updateChatDraftMessage, UpdateChatDraftMessage);
+  (updateChatHasScheduledMessages, UpdateChatHasScheduledMessages);
   (updateChatIsMarkedAsUnread, UpdateChatIsMarkedAsUnread);
   (updateChatIsPinned, UpdateChatIsPinned);
   (updateChatIsSponsored, UpdateChatIsSponsored);
@@ -543,6 +577,7 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (updateMessageContent, UpdateMessageContent);
   (updateMessageContentOpened, UpdateMessageContentOpened);
   (updateMessageEdited, UpdateMessageEdited);
+  (updateMessageLiveLocationViewed, UpdateMessageLiveLocationViewed);
   (updateMessageMentionRead, UpdateMessageMentionRead);
   (updateMessageSendAcknowledged, UpdateMessageSendAcknowledged);
   (updateMessageSendFailed, UpdateMessageSendFailed);
@@ -562,6 +597,7 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (updateNotificationGroup, UpdateNotificationGroup);
   (updateOption, UpdateOption);
   (updatePoll, UpdatePoll);
+  (updatePollAnswer, UpdatePollAnswer);
   (updateRecentStickers, UpdateRecentStickers);
   (updateSavedAnimations, UpdateSavedAnimations);
   (updateScopeNotificationSettings, UpdateScopeNotificationSettings);
@@ -579,12 +615,15 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (updateUserFullInfo, UpdateUserFullInfo);
   (updateUserPrivacySettingRules, UpdateUserPrivacySettingRules);
   (updateUserStatus, UpdateUserStatus);
+  (updateUsersNearby, UpdateUsersNearby);
 
   (AuthorizationState, AuthorizationState);
+  (CanTransferOwnershipResult, CanTransferOwnershipResult);
   (CheckChatUsernameResult, CheckChatUsernameResult);
   (JsonValue, JsonValue);
   (LanguagePackStringValue, LanguagePackStringValue);
   (LogStream, LogStream);
+  (LoginUrlInfo, LoginUrlInfo);
   (OptionValue, OptionValue);
   (PassportElement, PassportElement);
   (Update, Update);
@@ -599,13 +638,14 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (callId, CallId);
   (callbackQueryAnswer, CallbackQueryAnswer);
   (chat, Chat);
+  (chatAdministrators, ChatAdministrators);
   (chatEvents, ChatEvents);
   (chatInviteLink, ChatInviteLink);
   (chatInviteLinkInfo, ChatInviteLinkInfo);
   (chatMember, ChatMember);
   (chatMembers, ChatMembers);
-  (chatReportSpamState, ChatReportSpamState);
   (chats, Chats);
+  (chatsNearby, ChatsNearby);
   (connectedWebsites, ConnectedWebsites);
   (count, Count);
   (customRequestResult, CustomRequestResult);
@@ -649,6 +689,7 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (scopeNotificationSettings, ScopeNotificationSettings);
   (seconds, Seconds);
   (secretChat, SecretChat);
+  (session, Session);
   (sessions, Sessions);
   (stickerSet, StickerSet);
   (stickerSets, StickerSets);
@@ -693,8 +734,11 @@ impl RObject for TdType {
       Self::UpdateBasicGroup(value) => value.td_name(),
       Self::UpdateBasicGroupFullInfo(value) => value.td_name(),
       Self::UpdateCall(value) => value.td_name(),
+      Self::UpdateChatActionBar(value) => value.td_name(),
+      Self::UpdateChatChatList(value) => value.td_name(),
       Self::UpdateChatDefaultDisableNotification(value) => value.td_name(),
       Self::UpdateChatDraftMessage(value) => value.td_name(),
+      Self::UpdateChatHasScheduledMessages(value) => value.td_name(),
       Self::UpdateChatIsMarkedAsUnread(value) => value.td_name(),
       Self::UpdateChatIsPinned(value) => value.td_name(),
       Self::UpdateChatIsSponsored(value) => value.td_name(),
@@ -722,6 +766,7 @@ impl RObject for TdType {
       Self::UpdateMessageContent(value) => value.td_name(),
       Self::UpdateMessageContentOpened(value) => value.td_name(),
       Self::UpdateMessageEdited(value) => value.td_name(),
+      Self::UpdateMessageLiveLocationViewed(value) => value.td_name(),
       Self::UpdateMessageMentionRead(value) => value.td_name(),
       Self::UpdateMessageSendAcknowledged(value) => value.td_name(),
       Self::UpdateMessageSendFailed(value) => value.td_name(),
@@ -741,6 +786,7 @@ impl RObject for TdType {
       Self::UpdateNotificationGroup(value) => value.td_name(),
       Self::UpdateOption(value) => value.td_name(),
       Self::UpdatePoll(value) => value.td_name(),
+      Self::UpdatePollAnswer(value) => value.td_name(),
       Self::UpdateRecentStickers(value) => value.td_name(),
       Self::UpdateSavedAnimations(value) => value.td_name(),
       Self::UpdateScopeNotificationSettings(value) => value.td_name(),
@@ -758,12 +804,15 @@ impl RObject for TdType {
       Self::UpdateUserFullInfo(value) => value.td_name(),
       Self::UpdateUserPrivacySettingRules(value) => value.td_name(),
       Self::UpdateUserStatus(value) => value.td_name(),
+      Self::UpdateUsersNearby(value) => value.td_name(),
     
       Self::AuthorizationState(value) => value.td_name(),
+      Self::CanTransferOwnershipResult(value) => value.td_name(),
       Self::CheckChatUsernameResult(value) => value.td_name(),
       Self::JsonValue(value) => value.td_name(),
       Self::LanguagePackStringValue(value) => value.td_name(),
       Self::LogStream(value) => value.td_name(),
+      Self::LoginUrlInfo(value) => value.td_name(),
       Self::OptionValue(value) => value.td_name(),
       Self::PassportElement(value) => value.td_name(),
       Self::Update(value) => value.td_name(),
@@ -778,13 +827,14 @@ impl RObject for TdType {
       Self::CallId(value) => value.td_name(),
       Self::CallbackQueryAnswer(value) => value.td_name(),
       Self::Chat(value) => value.td_name(),
+      Self::ChatAdministrators(value) => value.td_name(),
       Self::ChatEvents(value) => value.td_name(),
       Self::ChatInviteLink(value) => value.td_name(),
       Self::ChatInviteLinkInfo(value) => value.td_name(),
       Self::ChatMember(value) => value.td_name(),
       Self::ChatMembers(value) => value.td_name(),
-      Self::ChatReportSpamState(value) => value.td_name(),
       Self::Chats(value) => value.td_name(),
+      Self::ChatsNearby(value) => value.td_name(),
       Self::ConnectedWebsites(value) => value.td_name(),
       Self::Count(value) => value.td_name(),
       Self::CustomRequestResult(value) => value.td_name(),
@@ -828,6 +878,7 @@ impl RObject for TdType {
       Self::ScopeNotificationSettings(value) => value.td_name(),
       Self::Seconds(value) => value.td_name(),
       Self::SecretChat(value) => value.td_name(),
+      Self::Session(value) => value.td_name(),
       Self::Sessions(value) => value.td_name(),
       Self::StickerSet(value) => value.td_name(),
       Self::StickerSets(value) => value.td_name(),
@@ -868,8 +919,11 @@ impl RObject for TdType {
         Self::UpdateBasicGroup(value) => value.extra(),
         Self::UpdateBasicGroupFullInfo(value) => value.extra(),
         Self::UpdateCall(value) => value.extra(),
+        Self::UpdateChatActionBar(value) => value.extra(),
+        Self::UpdateChatChatList(value) => value.extra(),
         Self::UpdateChatDefaultDisableNotification(value) => value.extra(),
         Self::UpdateChatDraftMessage(value) => value.extra(),
+        Self::UpdateChatHasScheduledMessages(value) => value.extra(),
         Self::UpdateChatIsMarkedAsUnread(value) => value.extra(),
         Self::UpdateChatIsPinned(value) => value.extra(),
         Self::UpdateChatIsSponsored(value) => value.extra(),
@@ -897,6 +951,7 @@ impl RObject for TdType {
         Self::UpdateMessageContent(value) => value.extra(),
         Self::UpdateMessageContentOpened(value) => value.extra(),
         Self::UpdateMessageEdited(value) => value.extra(),
+        Self::UpdateMessageLiveLocationViewed(value) => value.extra(),
         Self::UpdateMessageMentionRead(value) => value.extra(),
         Self::UpdateMessageSendAcknowledged(value) => value.extra(),
         Self::UpdateMessageSendFailed(value) => value.extra(),
@@ -916,6 +971,7 @@ impl RObject for TdType {
         Self::UpdateNotificationGroup(value) => value.extra(),
         Self::UpdateOption(value) => value.extra(),
         Self::UpdatePoll(value) => value.extra(),
+        Self::UpdatePollAnswer(value) => value.extra(),
         Self::UpdateRecentStickers(value) => value.extra(),
         Self::UpdateSavedAnimations(value) => value.extra(),
         Self::UpdateScopeNotificationSettings(value) => value.extra(),
@@ -933,12 +989,15 @@ impl RObject for TdType {
         Self::UpdateUserFullInfo(value) => value.extra(),
         Self::UpdateUserPrivacySettingRules(value) => value.extra(),
         Self::UpdateUserStatus(value) => value.extra(),
+        Self::UpdateUsersNearby(value) => value.extra(),
       
         Self::AuthorizationState(value) => value.extra(),
+        Self::CanTransferOwnershipResult(value) => value.extra(),
         Self::CheckChatUsernameResult(value) => value.extra(),
         Self::JsonValue(value) => value.extra(),
         Self::LanguagePackStringValue(value) => value.extra(),
         Self::LogStream(value) => value.extra(),
+        Self::LoginUrlInfo(value) => value.extra(),
         Self::OptionValue(value) => value.extra(),
         Self::PassportElement(value) => value.extra(),
         Self::Update(value) => value.extra(),
@@ -953,13 +1012,14 @@ impl RObject for TdType {
         Self::CallId(value) => value.extra(),
         Self::CallbackQueryAnswer(value) => value.extra(),
         Self::Chat(value) => value.extra(),
+        Self::ChatAdministrators(value) => value.extra(),
         Self::ChatEvents(value) => value.extra(),
         Self::ChatInviteLink(value) => value.extra(),
         Self::ChatInviteLinkInfo(value) => value.extra(),
         Self::ChatMember(value) => value.extra(),
         Self::ChatMembers(value) => value.extra(),
-        Self::ChatReportSpamState(value) => value.extra(),
         Self::Chats(value) => value.extra(),
+        Self::ChatsNearby(value) => value.extra(),
         Self::ConnectedWebsites(value) => value.extra(),
         Self::Count(value) => value.extra(),
         Self::CustomRequestResult(value) => value.extra(),
@@ -1003,6 +1063,7 @@ impl RObject for TdType {
         Self::ScopeNotificationSettings(value) => value.extra(),
         Self::Seconds(value) => value.extra(),
         Self::SecretChat(value) => value.extra(),
+        Self::Session(value) => value.extra(),
         Self::Sessions(value) => value.extra(),
         Self::StickerSet(value) => value.extra(),
         Self::StickerSets(value) => value.extra(),
@@ -1043,8 +1104,11 @@ impl RObject for TdType {
         Self::UpdateBasicGroup(value) => value.to_json(),
         Self::UpdateBasicGroupFullInfo(value) => value.to_json(),
         Self::UpdateCall(value) => value.to_json(),
+        Self::UpdateChatActionBar(value) => value.to_json(),
+        Self::UpdateChatChatList(value) => value.to_json(),
         Self::UpdateChatDefaultDisableNotification(value) => value.to_json(),
         Self::UpdateChatDraftMessage(value) => value.to_json(),
+        Self::UpdateChatHasScheduledMessages(value) => value.to_json(),
         Self::UpdateChatIsMarkedAsUnread(value) => value.to_json(),
         Self::UpdateChatIsPinned(value) => value.to_json(),
         Self::UpdateChatIsSponsored(value) => value.to_json(),
@@ -1072,6 +1136,7 @@ impl RObject for TdType {
         Self::UpdateMessageContent(value) => value.to_json(),
         Self::UpdateMessageContentOpened(value) => value.to_json(),
         Self::UpdateMessageEdited(value) => value.to_json(),
+        Self::UpdateMessageLiveLocationViewed(value) => value.to_json(),
         Self::UpdateMessageMentionRead(value) => value.to_json(),
         Self::UpdateMessageSendAcknowledged(value) => value.to_json(),
         Self::UpdateMessageSendFailed(value) => value.to_json(),
@@ -1091,6 +1156,7 @@ impl RObject for TdType {
         Self::UpdateNotificationGroup(value) => value.to_json(),
         Self::UpdateOption(value) => value.to_json(),
         Self::UpdatePoll(value) => value.to_json(),
+        Self::UpdatePollAnswer(value) => value.to_json(),
         Self::UpdateRecentStickers(value) => value.to_json(),
         Self::UpdateSavedAnimations(value) => value.to_json(),
         Self::UpdateScopeNotificationSettings(value) => value.to_json(),
@@ -1108,12 +1174,15 @@ impl RObject for TdType {
         Self::UpdateUserFullInfo(value) => value.to_json(),
         Self::UpdateUserPrivacySettingRules(value) => value.to_json(),
         Self::UpdateUserStatus(value) => value.to_json(),
+        Self::UpdateUsersNearby(value) => value.to_json(),
       
         Self::AuthorizationState(value) => value.to_json(),
+        Self::CanTransferOwnershipResult(value) => value.to_json(),
         Self::CheckChatUsernameResult(value) => value.to_json(),
         Self::JsonValue(value) => value.to_json(),
         Self::LanguagePackStringValue(value) => value.to_json(),
         Self::LogStream(value) => value.to_json(),
+        Self::LoginUrlInfo(value) => value.to_json(),
         Self::OptionValue(value) => value.to_json(),
         Self::PassportElement(value) => value.to_json(),
         Self::Update(value) => value.to_json(),
@@ -1128,13 +1197,14 @@ impl RObject for TdType {
         Self::CallId(value) => value.to_json(),
         Self::CallbackQueryAnswer(value) => value.to_json(),
         Self::Chat(value) => value.to_json(),
+        Self::ChatAdministrators(value) => value.to_json(),
         Self::ChatEvents(value) => value.to_json(),
         Self::ChatInviteLink(value) => value.to_json(),
         Self::ChatInviteLinkInfo(value) => value.to_json(),
         Self::ChatMember(value) => value.to_json(),
         Self::ChatMembers(value) => value.to_json(),
-        Self::ChatReportSpamState(value) => value.to_json(),
         Self::Chats(value) => value.to_json(),
+        Self::ChatsNearby(value) => value.to_json(),
         Self::ConnectedWebsites(value) => value.to_json(),
         Self::Count(value) => value.to_json(),
         Self::CustomRequestResult(value) => value.to_json(),
@@ -1178,6 +1248,7 @@ impl RObject for TdType {
         Self::ScopeNotificationSettings(value) => value.to_json(),
         Self::Seconds(value) => value.to_json(),
         Self::SecretChat(value) => value.to_json(),
+        Self::Session(value) => value.to_json(),
         Self::Sessions(value) => value.to_json(),
         Self::StickerSet(value) => value.to_json(),
         Self::StickerSets(value) => value.to_json(),
