@@ -17,12 +17,14 @@ pub struct AutoDownloadSettings {
   extra: Option<String>,
   /// True, if the auto-download is enabled
   is_auto_download_enabled: bool,
-  /// Maximum size of a photo file to be auto-downloaded
+  /// The maximum size of a photo file to be auto-downloaded
   max_photo_file_size: i64,
-  /// Maximum size of a video file to be auto-downloaded
+  /// The maximum size of a video file to be auto-downloaded
   max_video_file_size: i64,
-  /// Maximum size of other file types to be auto-downloaded
+  /// The maximum size of other file types to be auto-downloaded
   max_other_file_size: i64,
+  /// The maximum suggested bitrate for uploaded videos
+  video_upload_bitrate: i64,
   /// True, if the beginning of videos needs to be preloaded for instant playback
   preload_large_videos: bool,
   /// True, if the next audio track needs to be preloaded while the user is listening to an audio file
@@ -57,6 +59,8 @@ impl AutoDownloadSettings {
 
   pub fn max_other_file_size(&self) -> i64 { self.max_other_file_size }
 
+  pub fn video_upload_bitrate(&self) -> i64 { self.video_upload_bitrate }
+
   pub fn preload_large_videos(&self) -> bool { self.preload_large_videos }
 
   pub fn preload_next_audio(&self) -> bool { self.preload_next_audio }
@@ -98,6 +102,12 @@ impl RTDAutoDownloadSettingsBuilder {
   }
 
    
+  pub fn video_upload_bitrate(&mut self, video_upload_bitrate: i64) -> &mut Self {
+    self.inner.video_upload_bitrate = video_upload_bitrate;
+    self
+  }
+
+   
   pub fn preload_large_videos(&mut self, preload_large_videos: bool) -> &mut Self {
     self.inner.preload_large_videos = preload_large_videos;
     self
