@@ -25,6 +25,10 @@ pub enum ChatEventAction {
   ChatEventInvitesToggled(ChatEventInvitesToggled),
   /// The is_all_history_available setting of a supergroup was toggled
   ChatEventIsAllHistoryAvailableToggled(ChatEventIsAllHistoryAvailableToggled),
+  /// The linked chat of a supergroup was changed
+  ChatEventLinkedChatChanged(ChatEventLinkedChatChanged),
+  /// The supergroup location was changed
+  ChatEventLocationChanged(ChatEventLocationChanged),
   /// A new chat member was invited
   ChatEventMemberInvited(ChatEventMemberInvited),
   /// A new member joined the chat
@@ -51,6 +55,8 @@ pub enum ChatEventAction {
   ChatEventPollStopped(ChatEventPollStopped),
   /// The sign_messages setting of a channel was toggled
   ChatEventSignMessagesToggled(ChatEventSignMessagesToggled),
+  /// The slow_mode_delay setting of a supergroup was changed
+  ChatEventSlowModeDelayChanged(ChatEventSlowModeDelayChanged),
   /// The supergroup sticker set was changed
   ChatEventStickerSetChanged(ChatEventStickerSetChanged),
   /// The chat title was changed
@@ -72,6 +78,8 @@ impl<'de> Deserialize<'de> for ChatEventAction {
       (chatEventDescriptionChanged, ChatEventDescriptionChanged);
       (chatEventInvitesToggled, ChatEventInvitesToggled);
       (chatEventIsAllHistoryAvailableToggled, ChatEventIsAllHistoryAvailableToggled);
+      (chatEventLinkedChatChanged, ChatEventLinkedChatChanged);
+      (chatEventLocationChanged, ChatEventLocationChanged);
       (chatEventMemberInvited, ChatEventMemberInvited);
       (chatEventMemberJoined, ChatEventMemberJoined);
       (chatEventMemberLeft, ChatEventMemberLeft);
@@ -85,6 +93,7 @@ impl<'de> Deserialize<'de> for ChatEventAction {
       (chatEventPhotoChanged, ChatEventPhotoChanged);
       (chatEventPollStopped, ChatEventPollStopped);
       (chatEventSignMessagesToggled, ChatEventSignMessagesToggled);
+      (chatEventSlowModeDelayChanged, ChatEventSlowModeDelayChanged);
       (chatEventStickerSetChanged, ChatEventStickerSetChanged);
       (chatEventTitleChanged, ChatEventTitleChanged);
       (chatEventUsernameChanged, ChatEventUsernameChanged);
@@ -99,6 +108,8 @@ impl RObject for ChatEventAction {
       ChatEventAction::ChatEventDescriptionChanged(t) => t.td_name(),
       ChatEventAction::ChatEventInvitesToggled(t) => t.td_name(),
       ChatEventAction::ChatEventIsAllHistoryAvailableToggled(t) => t.td_name(),
+      ChatEventAction::ChatEventLinkedChatChanged(t) => t.td_name(),
+      ChatEventAction::ChatEventLocationChanged(t) => t.td_name(),
       ChatEventAction::ChatEventMemberInvited(t) => t.td_name(),
       ChatEventAction::ChatEventMemberJoined(t) => t.td_name(),
       ChatEventAction::ChatEventMemberLeft(t) => t.td_name(),
@@ -112,6 +123,7 @@ impl RObject for ChatEventAction {
       ChatEventAction::ChatEventPhotoChanged(t) => t.td_name(),
       ChatEventAction::ChatEventPollStopped(t) => t.td_name(),
       ChatEventAction::ChatEventSignMessagesToggled(t) => t.td_name(),
+      ChatEventAction::ChatEventSlowModeDelayChanged(t) => t.td_name(),
       ChatEventAction::ChatEventStickerSetChanged(t) => t.td_name(),
       ChatEventAction::ChatEventTitleChanged(t) => t.td_name(),
       ChatEventAction::ChatEventUsernameChanged(t) => t.td_name(),
@@ -124,6 +136,8 @@ impl RObject for ChatEventAction {
       ChatEventAction::ChatEventDescriptionChanged(t) => t.extra(),
       ChatEventAction::ChatEventInvitesToggled(t) => t.extra(),
       ChatEventAction::ChatEventIsAllHistoryAvailableToggled(t) => t.extra(),
+      ChatEventAction::ChatEventLinkedChatChanged(t) => t.extra(),
+      ChatEventAction::ChatEventLocationChanged(t) => t.extra(),
       ChatEventAction::ChatEventMemberInvited(t) => t.extra(),
       ChatEventAction::ChatEventMemberJoined(t) => t.extra(),
       ChatEventAction::ChatEventMemberLeft(t) => t.extra(),
@@ -137,6 +151,7 @@ impl RObject for ChatEventAction {
       ChatEventAction::ChatEventPhotoChanged(t) => t.extra(),
       ChatEventAction::ChatEventPollStopped(t) => t.extra(),
       ChatEventAction::ChatEventSignMessagesToggled(t) => t.extra(),
+      ChatEventAction::ChatEventSlowModeDelayChanged(t) => t.extra(),
       ChatEventAction::ChatEventStickerSetChanged(t) => t.extra(),
       ChatEventAction::ChatEventTitleChanged(t) => t.extra(),
       ChatEventAction::ChatEventUsernameChanged(t) => t.extra(),
@@ -154,6 +169,8 @@ impl ChatEventAction {
   pub fn is_chat_event_description_changed(&self) -> bool { if let ChatEventAction::ChatEventDescriptionChanged(_) = self { true } else { false } }
   pub fn is_chat_event_invites_toggled(&self) -> bool { if let ChatEventAction::ChatEventInvitesToggled(_) = self { true } else { false } }
   pub fn is_chat_event_is_all_history_available_toggled(&self) -> bool { if let ChatEventAction::ChatEventIsAllHistoryAvailableToggled(_) = self { true } else { false } }
+  pub fn is_chat_event_linked_chat_changed(&self) -> bool { if let ChatEventAction::ChatEventLinkedChatChanged(_) = self { true } else { false } }
+  pub fn is_chat_event_location_changed(&self) -> bool { if let ChatEventAction::ChatEventLocationChanged(_) = self { true } else { false } }
   pub fn is_chat_event_member_invited(&self) -> bool { if let ChatEventAction::ChatEventMemberInvited(_) = self { true } else { false } }
   pub fn is_chat_event_member_joined(&self) -> bool { if let ChatEventAction::ChatEventMemberJoined(_) = self { true } else { false } }
   pub fn is_chat_event_member_left(&self) -> bool { if let ChatEventAction::ChatEventMemberLeft(_) = self { true } else { false } }
@@ -167,6 +184,7 @@ impl ChatEventAction {
   pub fn is_chat_event_photo_changed(&self) -> bool { if let ChatEventAction::ChatEventPhotoChanged(_) = self { true } else { false } }
   pub fn is_chat_event_poll_stopped(&self) -> bool { if let ChatEventAction::ChatEventPollStopped(_) = self { true } else { false } }
   pub fn is_chat_event_sign_messages_toggled(&self) -> bool { if let ChatEventAction::ChatEventSignMessagesToggled(_) = self { true } else { false } }
+  pub fn is_chat_event_slow_mode_delay_changed(&self) -> bool { if let ChatEventAction::ChatEventSlowModeDelayChanged(_) = self { true } else { false } }
   pub fn is_chat_event_sticker_set_changed(&self) -> bool { if let ChatEventAction::ChatEventStickerSetChanged(_) = self { true } else { false } }
   pub fn is_chat_event_title_changed(&self) -> bool { if let ChatEventAction::ChatEventTitleChanged(_) = self { true } else { false } }
   pub fn is_chat_event_username_changed(&self) -> bool { if let ChatEventAction::ChatEventUsernameChanged(_) = self { true } else { false } }
@@ -174,6 +192,8 @@ impl ChatEventAction {
   pub fn on_chat_event_description_changed<F: FnOnce(&ChatEventDescriptionChanged)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventDescriptionChanged(t) = self { fnc(t) }; self }
   pub fn on_chat_event_invites_toggled<F: FnOnce(&ChatEventInvitesToggled)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventInvitesToggled(t) = self { fnc(t) }; self }
   pub fn on_chat_event_is_all_history_available_toggled<F: FnOnce(&ChatEventIsAllHistoryAvailableToggled)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventIsAllHistoryAvailableToggled(t) = self { fnc(t) }; self }
+  pub fn on_chat_event_linked_chat_changed<F: FnOnce(&ChatEventLinkedChatChanged)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventLinkedChatChanged(t) = self { fnc(t) }; self }
+  pub fn on_chat_event_location_changed<F: FnOnce(&ChatEventLocationChanged)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventLocationChanged(t) = self { fnc(t) }; self }
   pub fn on_chat_event_member_invited<F: FnOnce(&ChatEventMemberInvited)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventMemberInvited(t) = self { fnc(t) }; self }
   pub fn on_chat_event_member_joined<F: FnOnce(&ChatEventMemberJoined)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventMemberJoined(t) = self { fnc(t) }; self }
   pub fn on_chat_event_member_left<F: FnOnce(&ChatEventMemberLeft)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventMemberLeft(t) = self { fnc(t) }; self }
@@ -187,6 +207,7 @@ impl ChatEventAction {
   pub fn on_chat_event_photo_changed<F: FnOnce(&ChatEventPhotoChanged)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventPhotoChanged(t) = self { fnc(t) }; self }
   pub fn on_chat_event_poll_stopped<F: FnOnce(&ChatEventPollStopped)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventPollStopped(t) = self { fnc(t) }; self }
   pub fn on_chat_event_sign_messages_toggled<F: FnOnce(&ChatEventSignMessagesToggled)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventSignMessagesToggled(t) = self { fnc(t) }; self }
+  pub fn on_chat_event_slow_mode_delay_changed<F: FnOnce(&ChatEventSlowModeDelayChanged)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventSlowModeDelayChanged(t) = self { fnc(t) }; self }
   pub fn on_chat_event_sticker_set_changed<F: FnOnce(&ChatEventStickerSetChanged)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventStickerSetChanged(t) = self { fnc(t) }; self }
   pub fn on_chat_event_title_changed<F: FnOnce(&ChatEventTitleChanged)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventTitleChanged(t) = self { fnc(t) }; self }
   pub fn on_chat_event_username_changed<F: FnOnce(&ChatEventUsernameChanged)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventUsernameChanged(t) = self { fnc(t) }; self }
@@ -194,6 +215,8 @@ impl ChatEventAction {
   pub fn as_chat_event_description_changed(&self) -> Option<&ChatEventDescriptionChanged> { if let ChatEventAction::ChatEventDescriptionChanged(t) = self { return Some(t) } None }
   pub fn as_chat_event_invites_toggled(&self) -> Option<&ChatEventInvitesToggled> { if let ChatEventAction::ChatEventInvitesToggled(t) = self { return Some(t) } None }
   pub fn as_chat_event_is_all_history_available_toggled(&self) -> Option<&ChatEventIsAllHistoryAvailableToggled> { if let ChatEventAction::ChatEventIsAllHistoryAvailableToggled(t) = self { return Some(t) } None }
+  pub fn as_chat_event_linked_chat_changed(&self) -> Option<&ChatEventLinkedChatChanged> { if let ChatEventAction::ChatEventLinkedChatChanged(t) = self { return Some(t) } None }
+  pub fn as_chat_event_location_changed(&self) -> Option<&ChatEventLocationChanged> { if let ChatEventAction::ChatEventLocationChanged(t) = self { return Some(t) } None }
   pub fn as_chat_event_member_invited(&self) -> Option<&ChatEventMemberInvited> { if let ChatEventAction::ChatEventMemberInvited(t) = self { return Some(t) } None }
   pub fn as_chat_event_member_joined(&self) -> Option<&ChatEventMemberJoined> { if let ChatEventAction::ChatEventMemberJoined(t) = self { return Some(t) } None }
   pub fn as_chat_event_member_left(&self) -> Option<&ChatEventMemberLeft> { if let ChatEventAction::ChatEventMemberLeft(t) = self { return Some(t) } None }
@@ -207,6 +230,7 @@ impl ChatEventAction {
   pub fn as_chat_event_photo_changed(&self) -> Option<&ChatEventPhotoChanged> { if let ChatEventAction::ChatEventPhotoChanged(t) = self { return Some(t) } None }
   pub fn as_chat_event_poll_stopped(&self) -> Option<&ChatEventPollStopped> { if let ChatEventAction::ChatEventPollStopped(t) = self { return Some(t) } None }
   pub fn as_chat_event_sign_messages_toggled(&self) -> Option<&ChatEventSignMessagesToggled> { if let ChatEventAction::ChatEventSignMessagesToggled(t) = self { return Some(t) } None }
+  pub fn as_chat_event_slow_mode_delay_changed(&self) -> Option<&ChatEventSlowModeDelayChanged> { if let ChatEventAction::ChatEventSlowModeDelayChanged(t) = self { return Some(t) } None }
   pub fn as_chat_event_sticker_set_changed(&self) -> Option<&ChatEventStickerSetChanged> { if let ChatEventAction::ChatEventStickerSetChanged(t) = self { return Some(t) } None }
   pub fn as_chat_event_title_changed(&self) -> Option<&ChatEventTitleChanged> { if let ChatEventAction::ChatEventTitleChanged(t) = self { return Some(t) } None }
   pub fn as_chat_event_username_changed(&self) -> Option<&ChatEventUsernameChanged> { if let ChatEventAction::ChatEventUsernameChanged(t) = self { return Some(t) } None }
@@ -219,6 +243,10 @@ impl ChatEventAction {
 
   pub fn chat_event_is_all_history_available_toggled<T: AsRef<ChatEventIsAllHistoryAvailableToggled>>(t: T) -> Self { ChatEventAction::ChatEventIsAllHistoryAvailableToggled(t.as_ref().clone()) }
 
+  pub fn chat_event_linked_chat_changed<T: AsRef<ChatEventLinkedChatChanged>>(t: T) -> Self { ChatEventAction::ChatEventLinkedChatChanged(t.as_ref().clone()) }
+
+  pub fn chat_event_location_changed<T: AsRef<ChatEventLocationChanged>>(t: T) -> Self { ChatEventAction::ChatEventLocationChanged(t.as_ref().clone()) }
+
   pub fn chat_event_member_invited<T: AsRef<ChatEventMemberInvited>>(t: T) -> Self { ChatEventAction::ChatEventMemberInvited(t.as_ref().clone()) }
 
   pub fn chat_event_member_joined<T: AsRef<ChatEventMemberJoined>>(t: T) -> Self { ChatEventAction::ChatEventMemberJoined(t.as_ref().clone()) }
@@ -245,6 +273,8 @@ impl ChatEventAction {
 
   pub fn chat_event_sign_messages_toggled<T: AsRef<ChatEventSignMessagesToggled>>(t: T) -> Self { ChatEventAction::ChatEventSignMessagesToggled(t.as_ref().clone()) }
 
+  pub fn chat_event_slow_mode_delay_changed<T: AsRef<ChatEventSlowModeDelayChanged>>(t: T) -> Self { ChatEventAction::ChatEventSlowModeDelayChanged(t.as_ref().clone()) }
+
   pub fn chat_event_sticker_set_changed<T: AsRef<ChatEventStickerSetChanged>>(t: T) -> Self { ChatEventAction::ChatEventStickerSetChanged(t.as_ref().clone()) }
 
   pub fn chat_event_title_changed<T: AsRef<ChatEventTitleChanged>>(t: T) -> Self { ChatEventAction::ChatEventTitleChanged(t.as_ref().clone()) }
@@ -477,6 +507,162 @@ impl AsRef<ChatEventIsAllHistoryAvailableToggled> for RTDChatEventIsAllHistoryAv
 
 
 
+/// The linked chat of a supergroup was changed
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct ChatEventLinkedChatChanged {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  /// Previous supergroup linked chat identifier
+  old_linked_chat_id: i64,
+  /// New supergroup linked chat identifier
+  new_linked_chat_id: i64,
+  
+}
+
+impl RObject for ChatEventLinkedChatChanged {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "chatEventLinkedChatChanged" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDChatEventAction for ChatEventLinkedChatChanged {}
+
+
+
+impl ChatEventLinkedChatChanged {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDChatEventLinkedChatChangedBuilder {
+    let mut inner = ChatEventLinkedChatChanged::default();
+    inner.td_name = "chatEventLinkedChatChanged".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDChatEventLinkedChatChangedBuilder { inner }
+  }
+
+  pub fn old_linked_chat_id(&self) -> i64 { self.old_linked_chat_id }
+
+  pub fn new_linked_chat_id(&self) -> i64 { self.new_linked_chat_id }
+
+}
+
+#[doc(hidden)]
+pub struct RTDChatEventLinkedChatChangedBuilder {
+  inner: ChatEventLinkedChatChanged
+}
+
+impl RTDChatEventLinkedChatChangedBuilder {
+  pub fn build(&self) -> ChatEventLinkedChatChanged { self.inner.clone() }
+
+   
+  pub fn old_linked_chat_id(&mut self, old_linked_chat_id: i64) -> &mut Self {
+    self.inner.old_linked_chat_id = old_linked_chat_id;
+    self
+  }
+
+   
+  pub fn new_linked_chat_id(&mut self, new_linked_chat_id: i64) -> &mut Self {
+    self.inner.new_linked_chat_id = new_linked_chat_id;
+    self
+  }
+
+}
+
+impl AsRef<ChatEventLinkedChatChanged> for ChatEventLinkedChatChanged {
+  fn as_ref(&self) -> &ChatEventLinkedChatChanged { self }
+}
+
+impl AsRef<ChatEventLinkedChatChanged> for RTDChatEventLinkedChatChangedBuilder {
+  fn as_ref(&self) -> &ChatEventLinkedChatChanged { &self.inner }
+}
+
+
+
+
+
+
+
+/// The supergroup location was changed
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct ChatEventLocationChanged {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  /// Previous location; may be null
+  old_location: Option<ChatLocation>,
+  /// New location; may be null
+  new_location: Option<ChatLocation>,
+  
+}
+
+impl RObject for ChatEventLocationChanged {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "chatEventLocationChanged" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDChatEventAction for ChatEventLocationChanged {}
+
+
+
+impl ChatEventLocationChanged {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDChatEventLocationChangedBuilder {
+    let mut inner = ChatEventLocationChanged::default();
+    inner.td_name = "chatEventLocationChanged".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDChatEventLocationChangedBuilder { inner }
+  }
+
+  pub fn old_location(&self) -> &Option<ChatLocation> { &self.old_location }
+
+  pub fn new_location(&self) -> &Option<ChatLocation> { &self.new_location }
+
+}
+
+#[doc(hidden)]
+pub struct RTDChatEventLocationChangedBuilder {
+  inner: ChatEventLocationChanged
+}
+
+impl RTDChatEventLocationChangedBuilder {
+  pub fn build(&self) -> ChatEventLocationChanged { self.inner.clone() }
+
+   
+  pub fn old_location<T: AsRef<ChatLocation>>(&mut self, old_location: T) -> &mut Self {
+    self.inner.old_location = Some(old_location.as_ref().clone());
+    self
+  }
+
+   
+  pub fn new_location<T: AsRef<ChatLocation>>(&mut self, new_location: T) -> &mut Self {
+    self.inner.new_location = Some(new_location.as_ref().clone());
+    self
+  }
+
+}
+
+impl AsRef<ChatEventLocationChanged> for ChatEventLocationChanged {
+  fn as_ref(&self) -> &ChatEventLocationChanged { self }
+}
+
+impl AsRef<ChatEventLocationChanged> for RTDChatEventLocationChangedBuilder {
+  fn as_ref(&self) -> &ChatEventLocationChanged { &self.inner }
+}
+
+
+
+
+
+
+
 /// A new chat member was invited
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatEventMemberInvited {
@@ -1411,6 +1597,84 @@ impl AsRef<ChatEventSignMessagesToggled> for RTDChatEventSignMessagesToggledBuil
 
 
 
+/// The slow_mode_delay setting of a supergroup was changed
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct ChatEventSlowModeDelayChanged {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  /// Previous value of slow_mode_delay
+  old_slow_mode_delay: i64,
+  /// New value of slow_mode_delay
+  new_slow_mode_delay: i64,
+  
+}
+
+impl RObject for ChatEventSlowModeDelayChanged {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "chatEventSlowModeDelayChanged" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDChatEventAction for ChatEventSlowModeDelayChanged {}
+
+
+
+impl ChatEventSlowModeDelayChanged {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDChatEventSlowModeDelayChangedBuilder {
+    let mut inner = ChatEventSlowModeDelayChanged::default();
+    inner.td_name = "chatEventSlowModeDelayChanged".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDChatEventSlowModeDelayChangedBuilder { inner }
+  }
+
+  pub fn old_slow_mode_delay(&self) -> i64 { self.old_slow_mode_delay }
+
+  pub fn new_slow_mode_delay(&self) -> i64 { self.new_slow_mode_delay }
+
+}
+
+#[doc(hidden)]
+pub struct RTDChatEventSlowModeDelayChangedBuilder {
+  inner: ChatEventSlowModeDelayChanged
+}
+
+impl RTDChatEventSlowModeDelayChangedBuilder {
+  pub fn build(&self) -> ChatEventSlowModeDelayChanged { self.inner.clone() }
+
+   
+  pub fn old_slow_mode_delay(&mut self, old_slow_mode_delay: i64) -> &mut Self {
+    self.inner.old_slow_mode_delay = old_slow_mode_delay;
+    self
+  }
+
+   
+  pub fn new_slow_mode_delay(&mut self, new_slow_mode_delay: i64) -> &mut Self {
+    self.inner.new_slow_mode_delay = new_slow_mode_delay;
+    self
+  }
+
+}
+
+impl AsRef<ChatEventSlowModeDelayChanged> for ChatEventSlowModeDelayChanged {
+  fn as_ref(&self) -> &ChatEventSlowModeDelayChanged { self }
+}
+
+impl AsRef<ChatEventSlowModeDelayChanged> for RTDChatEventSlowModeDelayChangedBuilder {
+  fn as_ref(&self) -> &ChatEventSlowModeDelayChanged { &self.inner }
+}
+
+
+
+
+
+
+
 /// The supergroup sticker set was changed
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatEventStickerSetChanged {
