@@ -23,7 +23,7 @@ pub enum ChatMemberStatus {
   Administrator(ChatMemberStatusAdministrator),
   /// The user was banned (and hence is not a member of the chat). Implies the user can't return to the chat or view messages
   Banned(ChatMemberStatusBanned),
-  /// The user is the creator of a chat and has all the administrator privileges
+  /// The user is the owner of a chat and has all the administrator privileges
   Creator(ChatMemberStatusCreator),
   /// The user is not a chat member
   Left(ChatMemberStatusLeft),
@@ -142,6 +142,8 @@ pub struct ChatMemberStatusAdministrator {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
+  /// A custom title of the administrator; 0-16 characters without emojis; applicable to supergroups only
+  custom_title: String,
   /// True, if the current user can edit the administrator privileges for the called user
   can_be_edited: bool,
   /// True, if the administrator can change the chat title, photo, and other settings
@@ -158,7 +160,7 @@ pub struct ChatMemberStatusAdministrator {
   can_restrict_members: bool,
   /// True, if the administrator can pin messages; applicable to groups only
   can_pin_messages: bool,
-  /// True, if the administrator can add new administrators with a subset of their own privileges or demote administrators that were directly or indirectly promoted by him
+  /// True, if the administrator can add new administrators with a subset of their own privileges or demote administrators that were directly or indirectly promoted by them
   can_promote_members: bool,
   
 }
@@ -183,6 +185,8 @@ impl ChatMemberStatusAdministrator {
     RTDChatMemberStatusAdministratorBuilder { inner }
   }
 
+  pub fn custom_title(&self) -> &String { &self.custom_title }
+
   pub fn can_be_edited(&self) -> bool { self.can_be_edited }
 
   pub fn can_change_info(&self) -> bool { self.can_change_info }
@@ -212,6 +216,12 @@ impl RTDChatMemberStatusAdministratorBuilder {
   pub fn build(&self) -> ChatMemberStatusAdministrator { self.inner.clone() }
 
    
+  pub fn custom_title<T: AsRef<str>>(&mut self, custom_title: T) -> &mut Self {
+    self.inner.custom_title = custom_title.as_ref().to_string();
+    self
+  }
+
+   
   pub fn can_be_edited(&mut self, can_be_edited: bool) -> &mut Self {
     self.inner.can_be_edited = can_be_edited;
     self
@@ -349,7 +359,7 @@ impl AsRef<ChatMemberStatusBanned> for RTDChatMemberStatusBannedBuilder {
 
 
 
-/// The user is the creator of a chat and has all the administrator privileges
+/// The user is the owner of a chat and has all the administrator privileges
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatMemberStatusCreator {
   #[doc(hidden)]
@@ -358,6 +368,8 @@ pub struct ChatMemberStatusCreator {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
+  /// A custom title of the owner; 0-16 characters without emojis; applicable to supergroups only
+  custom_title: String,
   /// True, if the user is a member of the chat
   is_member: bool,
   
@@ -383,6 +395,8 @@ impl ChatMemberStatusCreator {
     RTDChatMemberStatusCreatorBuilder { inner }
   }
 
+  pub fn custom_title(&self) -> &String { &self.custom_title }
+
   pub fn is_member(&self) -> bool { self.is_member }
 
 }
@@ -396,6 +410,12 @@ impl RTDChatMemberStatusCreatorBuilder {
   pub fn build(&self) -> ChatMemberStatusCreator { self.inner.clone() }
 
    
+  pub fn custom_title<T: AsRef<str>>(&mut self, custom_title: T) -> &mut Self {
+    self.inner.custom_title = custom_title.as_ref().to_string();
+    self
+  }
+
+   
   pub fn is_member(&mut self, is_member: bool) -> &mut Self {
     self.inner.is_member = is_member;
     self
