@@ -11,10 +11,10 @@ use serde::de::{Deserialize, Deserializer};
 
 
 
-/// TRAIT | Represents a data needed to subscribe for push notifications. To use specific push notification service, you must specify the correct application platform and upload valid server authentication data at https://my.telegram.org
+/// TRAIT | Represents a data needed to subscribe for push notifications through registerDevice method. To use specific push notification service, you must specify the correct application platform and upload valid server authentication data at https://my.telegram.org
 pub trait TDDeviceToken: Debug + RObject {}
 
-/// Represents a data needed to subscribe for push notifications. To use specific push notification service, you must specify the correct application platform and upload valid server authentication data at https://my.telegram.org
+/// Represents a data needed to subscribe for push notifications through registerDevice method. To use specific push notification service, you must specify the correct application platform and upload valid server authentication data at https://my.telegram.org
 #[derive(Debug, Clone, Serialize)]
 #[serde(untagged)]
 pub enum DeviceToken {
@@ -25,8 +25,8 @@ pub enum DeviceToken {
   ApplePushVoIP(DeviceTokenApplePushVoIP),
   /// A token for BlackBerry Push Service
   BlackBerryPush(DeviceTokenBlackBerryPush),
-  /// A token for Google Cloud Messaging
-  GoogleCloudMessaging(DeviceTokenGoogleCloudMessaging),
+  /// A token for Firebase Cloud Messaging
+  FirebaseCloudMessaging(DeviceTokenFirebaseCloudMessaging),
   /// A token for Microsoft Push Notification Service
   MicrosoftPush(DeviceTokenMicrosoftPush),
   /// A token for Microsoft Push Notification Service VoIP channel
@@ -56,7 +56,7 @@ impl<'de> Deserialize<'de> for DeviceToken {
       (deviceTokenApplePush, ApplePush);
       (deviceTokenApplePushVoIP, ApplePushVoIP);
       (deviceTokenBlackBerryPush, BlackBerryPush);
-      (deviceTokenGoogleCloudMessaging, GoogleCloudMessaging);
+      (deviceTokenFirebaseCloudMessaging, FirebaseCloudMessaging);
       (deviceTokenMicrosoftPush, MicrosoftPush);
       (deviceTokenMicrosoftPushVoIP, MicrosoftPushVoIP);
       (deviceTokenSimplePush, SimplePush);
@@ -75,7 +75,7 @@ impl RObject for DeviceToken {
       DeviceToken::ApplePush(t) => t.td_name(),
       DeviceToken::ApplePushVoIP(t) => t.td_name(),
       DeviceToken::BlackBerryPush(t) => t.td_name(),
-      DeviceToken::GoogleCloudMessaging(t) => t.td_name(),
+      DeviceToken::FirebaseCloudMessaging(t) => t.td_name(),
       DeviceToken::MicrosoftPush(t) => t.td_name(),
       DeviceToken::MicrosoftPushVoIP(t) => t.td_name(),
       DeviceToken::SimplePush(t) => t.td_name(),
@@ -92,7 +92,7 @@ impl RObject for DeviceToken {
       DeviceToken::ApplePush(t) => t.extra(),
       DeviceToken::ApplePushVoIP(t) => t.extra(),
       DeviceToken::BlackBerryPush(t) => t.extra(),
-      DeviceToken::GoogleCloudMessaging(t) => t.extra(),
+      DeviceToken::FirebaseCloudMessaging(t) => t.extra(),
       DeviceToken::MicrosoftPush(t) => t.extra(),
       DeviceToken::MicrosoftPushVoIP(t) => t.extra(),
       DeviceToken::SimplePush(t) => t.extra(),
@@ -114,7 +114,7 @@ impl DeviceToken {
   pub fn is_apple_push(&self) -> bool { if let DeviceToken::ApplePush(_) = self { true } else { false } }
   pub fn is_apple_push_vo_i_p(&self) -> bool { if let DeviceToken::ApplePushVoIP(_) = self { true } else { false } }
   pub fn is_black_berry_push(&self) -> bool { if let DeviceToken::BlackBerryPush(_) = self { true } else { false } }
-  pub fn is_google_cloud_messaging(&self) -> bool { if let DeviceToken::GoogleCloudMessaging(_) = self { true } else { false } }
+  pub fn is_firebase_cloud_messaging(&self) -> bool { if let DeviceToken::FirebaseCloudMessaging(_) = self { true } else { false } }
   pub fn is_microsoft_push(&self) -> bool { if let DeviceToken::MicrosoftPush(_) = self { true } else { false } }
   pub fn is_microsoft_push_vo_i_p(&self) -> bool { if let DeviceToken::MicrosoftPushVoIP(_) = self { true } else { false } }
   pub fn is_simple_push(&self) -> bool { if let DeviceToken::SimplePush(_) = self { true } else { false } }
@@ -126,7 +126,7 @@ impl DeviceToken {
   pub fn on_apple_push<F: FnOnce(&DeviceTokenApplePush)>(&self, fnc: F) -> &Self { if let DeviceToken::ApplePush(t) = self { fnc(t) }; self }
   pub fn on_apple_push_vo_i_p<F: FnOnce(&DeviceTokenApplePushVoIP)>(&self, fnc: F) -> &Self { if let DeviceToken::ApplePushVoIP(t) = self { fnc(t) }; self }
   pub fn on_black_berry_push<F: FnOnce(&DeviceTokenBlackBerryPush)>(&self, fnc: F) -> &Self { if let DeviceToken::BlackBerryPush(t) = self { fnc(t) }; self }
-  pub fn on_google_cloud_messaging<F: FnOnce(&DeviceTokenGoogleCloudMessaging)>(&self, fnc: F) -> &Self { if let DeviceToken::GoogleCloudMessaging(t) = self { fnc(t) }; self }
+  pub fn on_firebase_cloud_messaging<F: FnOnce(&DeviceTokenFirebaseCloudMessaging)>(&self, fnc: F) -> &Self { if let DeviceToken::FirebaseCloudMessaging(t) = self { fnc(t) }; self }
   pub fn on_microsoft_push<F: FnOnce(&DeviceTokenMicrosoftPush)>(&self, fnc: F) -> &Self { if let DeviceToken::MicrosoftPush(t) = self { fnc(t) }; self }
   pub fn on_microsoft_push_vo_i_p<F: FnOnce(&DeviceTokenMicrosoftPushVoIP)>(&self, fnc: F) -> &Self { if let DeviceToken::MicrosoftPushVoIP(t) = self { fnc(t) }; self }
   pub fn on_simple_push<F: FnOnce(&DeviceTokenSimplePush)>(&self, fnc: F) -> &Self { if let DeviceToken::SimplePush(t) = self { fnc(t) }; self }
@@ -138,7 +138,7 @@ impl DeviceToken {
   pub fn as_apple_push(&self) -> Option<&DeviceTokenApplePush> { if let DeviceToken::ApplePush(t) = self { return Some(t) } None }
   pub fn as_apple_push_vo_i_p(&self) -> Option<&DeviceTokenApplePushVoIP> { if let DeviceToken::ApplePushVoIP(t) = self { return Some(t) } None }
   pub fn as_black_berry_push(&self) -> Option<&DeviceTokenBlackBerryPush> { if let DeviceToken::BlackBerryPush(t) = self { return Some(t) } None }
-  pub fn as_google_cloud_messaging(&self) -> Option<&DeviceTokenGoogleCloudMessaging> { if let DeviceToken::GoogleCloudMessaging(t) = self { return Some(t) } None }
+  pub fn as_firebase_cloud_messaging(&self) -> Option<&DeviceTokenFirebaseCloudMessaging> { if let DeviceToken::FirebaseCloudMessaging(t) = self { return Some(t) } None }
   pub fn as_microsoft_push(&self) -> Option<&DeviceTokenMicrosoftPush> { if let DeviceToken::MicrosoftPush(t) = self { return Some(t) } None }
   pub fn as_microsoft_push_vo_i_p(&self) -> Option<&DeviceTokenMicrosoftPushVoIP> { if let DeviceToken::MicrosoftPushVoIP(t) = self { return Some(t) } None }
   pub fn as_simple_push(&self) -> Option<&DeviceTokenSimplePush> { if let DeviceToken::SimplePush(t) = self { return Some(t) } None }
@@ -155,7 +155,7 @@ impl DeviceToken {
 
   pub fn black_berry_push<T: AsRef<DeviceTokenBlackBerryPush>>(t: T) -> Self { DeviceToken::BlackBerryPush(t.as_ref().clone()) }
 
-  pub fn google_cloud_messaging<T: AsRef<DeviceTokenGoogleCloudMessaging>>(t: T) -> Self { DeviceToken::GoogleCloudMessaging(t.as_ref().clone()) }
+  pub fn firebase_cloud_messaging<T: AsRef<DeviceTokenFirebaseCloudMessaging>>(t: T) -> Self { DeviceToken::FirebaseCloudMessaging(t.as_ref().clone()) }
 
   pub fn microsoft_push<T: AsRef<DeviceTokenMicrosoftPush>>(t: T) -> Self { DeviceToken::MicrosoftPush(t.as_ref().clone()) }
 
@@ -274,6 +274,8 @@ pub struct DeviceTokenApplePushVoIP {
   device_token: String,
   /// True, if App Sandbox is enabled
   is_app_sandbox: bool,
+  /// True, if push notifications should be additionally encrypted
+  encrypt: bool,
   
 }
 
@@ -301,6 +303,8 @@ impl DeviceTokenApplePushVoIP {
 
   pub fn is_app_sandbox(&self) -> bool { self.is_app_sandbox }
 
+  pub fn encrypt(&self) -> bool { self.encrypt }
+
 }
 
 #[doc(hidden)]
@@ -323,6 +327,12 @@ impl RTDDeviceTokenApplePushVoIPBuilder {
     self
   }
 
+   
+  pub fn encrypt(&mut self, encrypt: bool) -> &mut Self {
+    self.inner.encrypt = encrypt;
+    self
+  }
+
 }
 
 impl AsRef<DeviceTokenApplePushVoIP> for DeviceTokenApplePushVoIP {
@@ -407,9 +417,9 @@ impl AsRef<DeviceTokenBlackBerryPush> for RTDDeviceTokenBlackBerryPushBuilder {
 
 
 
-/// A token for Google Cloud Messaging
+/// A token for Firebase Cloud Messaging
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
-pub struct DeviceTokenGoogleCloudMessaging {
+pub struct DeviceTokenFirebaseCloudMessaging {
   #[doc(hidden)]
   #[serde(rename(serialize = "@type", deserialize = "@type"))]
   td_name: String,
@@ -418,40 +428,44 @@ pub struct DeviceTokenGoogleCloudMessaging {
   extra: Option<String>,
   /// Device registration token; may be empty to de-register a device
   token: String,
+  /// True, if push notifications should be additionally encrypted
+  encrypt: bool,
   
 }
 
-impl RObject for DeviceTokenGoogleCloudMessaging {
-  #[doc(hidden)] fn td_name(&self) -> &'static str { "deviceTokenGoogleCloudMessaging" }
+impl RObject for DeviceTokenFirebaseCloudMessaging {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "deviceTokenFirebaseCloudMessaging" }
   #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
   fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
 }
 
 
-impl TDDeviceToken for DeviceTokenGoogleCloudMessaging {}
+impl TDDeviceToken for DeviceTokenFirebaseCloudMessaging {}
 
 
 
-impl DeviceTokenGoogleCloudMessaging {
+impl DeviceTokenFirebaseCloudMessaging {
   pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
-  pub fn builder() -> RTDDeviceTokenGoogleCloudMessagingBuilder {
-    let mut inner = DeviceTokenGoogleCloudMessaging::default();
-    inner.td_name = "deviceTokenGoogleCloudMessaging".to_string();
+  pub fn builder() -> RTDDeviceTokenFirebaseCloudMessagingBuilder {
+    let mut inner = DeviceTokenFirebaseCloudMessaging::default();
+    inner.td_name = "deviceTokenFirebaseCloudMessaging".to_string();
     inner.extra = Some(Uuid::new_v4().to_string());
-    RTDDeviceTokenGoogleCloudMessagingBuilder { inner }
+    RTDDeviceTokenFirebaseCloudMessagingBuilder { inner }
   }
 
   pub fn token(&self) -> &String { &self.token }
 
+  pub fn encrypt(&self) -> bool { self.encrypt }
+
 }
 
 #[doc(hidden)]
-pub struct RTDDeviceTokenGoogleCloudMessagingBuilder {
-  inner: DeviceTokenGoogleCloudMessaging
+pub struct RTDDeviceTokenFirebaseCloudMessagingBuilder {
+  inner: DeviceTokenFirebaseCloudMessaging
 }
 
-impl RTDDeviceTokenGoogleCloudMessagingBuilder {
-  pub fn build(&self) -> DeviceTokenGoogleCloudMessaging { self.inner.clone() }
+impl RTDDeviceTokenFirebaseCloudMessagingBuilder {
+  pub fn build(&self) -> DeviceTokenFirebaseCloudMessaging { self.inner.clone() }
 
    
   pub fn token<T: AsRef<str>>(&mut self, token: T) -> &mut Self {
@@ -459,14 +473,20 @@ impl RTDDeviceTokenGoogleCloudMessagingBuilder {
     self
   }
 
+   
+  pub fn encrypt(&mut self, encrypt: bool) -> &mut Self {
+    self.inner.encrypt = encrypt;
+    self
+  }
+
 }
 
-impl AsRef<DeviceTokenGoogleCloudMessaging> for DeviceTokenGoogleCloudMessaging {
-  fn as_ref(&self) -> &DeviceTokenGoogleCloudMessaging { self }
+impl AsRef<DeviceTokenFirebaseCloudMessaging> for DeviceTokenFirebaseCloudMessaging {
+  fn as_ref(&self) -> &DeviceTokenFirebaseCloudMessaging { self }
 }
 
-impl AsRef<DeviceTokenGoogleCloudMessaging> for RTDDeviceTokenGoogleCloudMessagingBuilder {
-  fn as_ref(&self) -> &DeviceTokenGoogleCloudMessaging { &self.inner }
+impl AsRef<DeviceTokenFirebaseCloudMessaging> for RTDDeviceTokenFirebaseCloudMessagingBuilder {
+  fn as_ref(&self) -> &DeviceTokenFirebaseCloudMessaging { &self.inner }
 }
 
 
