@@ -37,7 +37,7 @@ pub enum InputMessageContent {
   InputMessageLocation(InputMessageLocation),
   /// A photo message
   InputMessagePhoto(InputMessagePhoto),
-  /// A message with a poll. Polls can't be sent to private or secret chats
+  /// A message with a poll. Polls can't be sent to secret chats. Polls can be sent only to a private chat with a bot
   InputMessagePoll(InputMessagePoll),
   /// A sticker message
   InputMessageSticker(InputMessageSticker),
@@ -990,7 +990,7 @@ pub struct InputMessageLocation {
   extra: Option<String>,
   /// Location to be sent
   location: Location,
-  /// Period for which the location can be updated, in seconds; should bebetween 60 and 86400 for a live location and 0 otherwise
+  /// Period for which the location can be updated, in seconds; should be between 60 and 86400 for a live location and 0 otherwise
   live_period: i64,
   
 }
@@ -1185,7 +1185,7 @@ impl AsRef<InputMessagePhoto> for RTDInputMessagePhotoBuilder {
 
 
 
-/// A message with a poll. Polls can't be sent to private or secret chats
+/// A message with a poll. Polls can't be sent to secret chats. Polls can be sent only to a private chat with a bot
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct InputMessagePoll {
   #[doc(hidden)]
@@ -1198,6 +1198,12 @@ pub struct InputMessagePoll {
   question: String,
   /// List of poll answer options, 2-10 strings 1-100 characters each
   options: Vec<String>,
+  /// True, if the poll voters are anonymous. Non-anonymous polls can't be sent or forwarded to channels
+  is_anonymous: bool,
+  /// Type of the poll
+  #[serde(rename(serialize = "type", deserialize = "type"))] type_: PollType,
+  /// True, if the poll needs to be sent already closed; for bots only
+  is_closed: bool,
   
 }
 
@@ -1225,6 +1231,12 @@ impl InputMessagePoll {
 
   pub fn options(&self) -> &Vec<String> { &self.options }
 
+  pub fn is_anonymous(&self) -> bool { self.is_anonymous }
+
+  pub fn type_(&self) -> &PollType { &self.type_ }
+
+  pub fn is_closed(&self) -> bool { self.is_closed }
+
 }
 
 #[doc(hidden)]
@@ -1247,6 +1259,24 @@ impl RTDInputMessagePollBuilder {
     self
   }
 
+   
+  pub fn is_anonymous(&mut self, is_anonymous: bool) -> &mut Self {
+    self.inner.is_anonymous = is_anonymous;
+    self
+  }
+
+   
+  pub fn type_<T: AsRef<PollType>>(&mut self, type_: T) -> &mut Self {
+    self.inner.type_ = type_.as_ref().clone();
+    self
+  }
+
+   
+  pub fn is_closed(&mut self, is_closed: bool) -> &mut Self {
+    self.inner.is_closed = is_closed;
+    self
+  }
+
 }
 
 impl AsRef<InputMessagePoll> for InputMessagePoll {
@@ -1370,7 +1400,7 @@ pub struct InputMessageText {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// Formatted text to be sent; 1-GetOption("message_text_length_max") characters. Only Bold, Italic, Code, Pre, PreCode and TextUrl entities are allowed to be specified manually
+  /// Formatted text to be sent; 1-GetOption("message_text_length_max") characters. Only Bold, Italic, Underline, Strikethrough, Code, Pre, PreCode, TextUrl and MentionName entities are allowed to be specified manually
   text: FormattedText,
   /// True, if rich web page previews for URLs in the message text should be disabled
   disable_web_page_preview: bool,
