@@ -23,9 +23,11 @@ pub struct Message {
   chat_id: i64,
   /// Information about the sending state of the message; may be null
   sending_state: Option<MessageSendingState>,
+  /// Information about the scheduling state of the message; may be null
+  scheduling_state: Option<MessageSchedulingState>,
   /// True, if the message is outgoing
   is_outgoing: bool,
-  /// True, if the message can be edited. For live location and poll messages this fields shows, whether editMessageLiveLocation or stopPoll can be used with this message by the client
+  /// True, if the message can be edited. For live location and poll messages this fields shows whether editMessageLiveLocation or stopPoll can be used with this message by the client
   can_be_edited: bool,
   /// True, if the message can be forwarded
   can_be_forwarded: bool,
@@ -57,6 +59,8 @@ pub struct Message {
   views: i64,
   /// Unique identifier of an album this message belongs to. Only photos and videos can be grouped together in albums
   #[serde(deserialize_with = "serde_aux::field_attributes::deserialize_number_from_string")] media_album_id: isize,
+  /// If non-empty, contains a human-readable description of the reason why access to this message must be restricted
+  restriction_reason: String,
   /// Content of the message
   content: MessageContent,
   /// Reply markup for the message; may be null
@@ -89,6 +93,8 @@ impl Message {
 
   pub fn sending_state(&self) -> &Option<MessageSendingState> { &self.sending_state }
 
+  pub fn scheduling_state(&self) -> &Option<MessageSchedulingState> { &self.scheduling_state }
+
   pub fn is_outgoing(&self) -> bool { self.is_outgoing }
 
   pub fn can_be_edited(&self) -> bool { self.can_be_edited }
@@ -123,6 +129,8 @@ impl Message {
 
   pub fn media_album_id(&self) -> isize { self.media_album_id }
 
+  pub fn restriction_reason(&self) -> &String { &self.restriction_reason }
+
   pub fn content(&self) -> &MessageContent { &self.content }
 
   pub fn reply_markup(&self) -> &Option<ReplyMarkup> { &self.reply_markup }
@@ -162,6 +170,12 @@ impl RTDMessageBuilder {
   }
 
    
+  pub fn scheduling_state<T: AsRef<MessageSchedulingState>>(&mut self, scheduling_state: T) -> &mut Self {
+    self.inner.scheduling_state = Some(scheduling_state.as_ref().clone());
+    self
+  }
+
+   
   pub fn is_outgoing(&mut self, is_outgoing: bool) -> &mut Self {
     self.inner.is_outgoing = is_outgoing;
     self
@@ -264,6 +278,12 @@ impl RTDMessageBuilder {
   }
 
    
+  pub fn restriction_reason<T: AsRef<str>>(&mut self, restriction_reason: T) -> &mut Self {
+    self.inner.restriction_reason = restriction_reason.as_ref().to_string();
+    self
+  }
+
+   
   pub fn content<T: AsRef<MessageContent>>(&mut self, content: T) -> &mut Self {
     self.inner.content = content.as_ref().clone();
     self
