@@ -21,12 +21,8 @@ pub struct MessageLinkInfo {
   chat_id: i64,
   /// If found, the linked message; may be null
   message: Option<Message>,
-  /// Timestamp from which the video/audio/video note/voice note playing must start, in seconds; 0 if not specified. The media can be in the message content or in its web page preview
-  media_timestamp: i64,
   /// True, if the whole media album to which the message belongs is linked
   for_album: bool,
-  /// True, if the message is linked as a channel post comment or from a message thread
-  for_comment: bool,
   
 }
 
@@ -53,12 +49,8 @@ impl MessageLinkInfo {
 
   pub fn message(&self) -> &Option<Message> { &self.message }
 
-  pub fn media_timestamp(&self) -> i64 { self.media_timestamp }
-
   pub fn for_album(&self) -> bool { self.for_album }
 
-  pub fn for_comment(&self) -> bool { self.for_comment }
-
 }
 
 #[doc(hidden)]
@@ -88,23 +80,11 @@ impl RTDMessageLinkInfoBuilder {
   }
 
    
-  pub fn media_timestamp(&mut self, media_timestamp: i64) -> &mut Self {
-    self.inner.media_timestamp = media_timestamp;
-    self
-  }
-
-   
   pub fn for_album(&mut self, for_album: bool) -> &mut Self {
     self.inner.for_album = for_album;
     self
   }
 
-   
-  pub fn for_comment(&mut self, for_comment: bool) -> &mut Self {
-    self.inner.for_comment = for_comment;
-    self
-  }
-
 }
 
 impl AsRef<MessageLinkInfo> for MessageLinkInfo {
