@@ -21,6 +21,7 @@ pub use self::authorization_state::*;
 pub use self::auto_download_settings::*;
 pub use self::auto_download_settings_presets::*;
 pub use self::background::*;
+pub use self::background_fill::*;
 pub use self::background_type::*;
 pub use self::backgrounds::*;
 pub use self::basic_group::*;
@@ -36,25 +37,32 @@ pub use self::call_protocol::*;
 pub use self::call_state::*;
 pub use self::callback_query_answer::*;
 pub use self::callback_query_payload::*;
+pub use self::can_transfer_ownership_result::*;
 pub use self::chat::*;
 pub use self::chat_action::*;
+pub use self::chat_action_bar::*;
+pub use self::chat_administrator::*;
+pub use self::chat_administrators::*;
 pub use self::chat_event::*;
 pub use self::chat_event_action::*;
 pub use self::chat_event_log_filters::*;
 pub use self::chat_events::*;
 pub use self::chat_invite_link::*;
 pub use self::chat_invite_link_info::*;
+pub use self::chat_list::*;
+pub use self::chat_location::*;
 pub use self::chat_member::*;
 pub use self::chat_member_status::*;
 pub use self::chat_members::*;
 pub use self::chat_members_filter::*;
+pub use self::chat_nearby::*;
 pub use self::chat_notification_settings::*;
 pub use self::chat_permissions::*;
 pub use self::chat_photo::*;
 pub use self::chat_report_reason::*;
-pub use self::chat_report_spam_state::*;
 pub use self::chat_type::*;
 pub use self::chats::*;
+pub use self::chats_nearby::*;
 pub use self::check_chat_username_result::*;
 pub use self::connected_website::*;
 pub use self::connected_websites::*;
@@ -113,13 +121,13 @@ pub use self::language_pack_info::*;
 pub use self::language_pack_string::*;
 pub use self::language_pack_string_value::*;
 pub use self::language_pack_strings::*;
-pub use self::link_state::*;
 pub use self::local_file::*;
 pub use self::localization_target_info::*;
 pub use self::location::*;
 pub use self::log_stream::*;
 pub use self::log_tags::*;
 pub use self::log_verbosity_level::*;
+pub use self::login_url_info::*;
 pub use self::mask_point::*;
 pub use self::mask_position::*;
 pub use self::message::*;
@@ -127,6 +135,7 @@ pub use self::message_content::*;
 pub use self::message_forward_info::*;
 pub use self::message_forward_origin::*;
 pub use self::message_link_info::*;
+pub use self::message_scheduling_state::*;
 pub use self::message_sending_state::*;
 pub use self::messages::*;
 pub use self::minithumbnail::*;
@@ -169,10 +178,12 @@ pub use self::photo::*;
 pub use self::photo_size::*;
 pub use self::poll::*;
 pub use self::poll_option::*;
+pub use self::poll_type::*;
 pub use self::profile_photo::*;
 pub use self::proxies::*;
 pub use self::proxy::*;
 pub use self::proxy_type::*;
+pub use self::public_chat_type::*;
 pub use self::public_message_link::*;
 pub use self::push_message_content::*;
 pub use self::push_receiver_id::*;
@@ -186,6 +197,7 @@ pub use self::search_messages_filter::*;
 pub use self::seconds::*;
 pub use self::secret_chat::*;
 pub use self::secret_chat_state::*;
+pub use self::send_message_options::*;
 pub use self::session::*;
 pub use self::sessions::*;
 pub use self::shipping_option::*;
@@ -254,6 +266,7 @@ mod authorization_state;
 mod auto_download_settings;
 mod auto_download_settings_presets;
 mod background;
+mod background_fill;
 mod background_type;
 mod backgrounds;
 mod basic_group;
@@ -269,25 +282,32 @@ mod call_protocol;
 mod call_state;
 mod callback_query_answer;
 mod callback_query_payload;
+mod can_transfer_ownership_result;
 mod chat;
 mod chat_action;
+mod chat_action_bar;
+mod chat_administrator;
+mod chat_administrators;
 mod chat_event;
 mod chat_event_action;
 mod chat_event_log_filters;
 mod chat_events;
 mod chat_invite_link;
 mod chat_invite_link_info;
+mod chat_list;
+mod chat_location;
 mod chat_member;
 mod chat_member_status;
 mod chat_members;
 mod chat_members_filter;
+mod chat_nearby;
 mod chat_notification_settings;
 mod chat_permissions;
 mod chat_photo;
 mod chat_report_reason;
-mod chat_report_spam_state;
 mod chat_type;
 mod chats;
+mod chats_nearby;
 mod check_chat_username_result;
 mod connected_website;
 mod connected_websites;
@@ -346,13 +366,13 @@ mod language_pack_info;
 mod language_pack_string;
 mod language_pack_string_value;
 mod language_pack_strings;
-mod link_state;
 mod local_file;
 mod localization_target_info;
 mod location;
 mod log_stream;
 mod log_tags;
 mod log_verbosity_level;
+mod login_url_info;
 mod mask_point;
 mod mask_position;
 mod message;
@@ -360,6 +380,7 @@ mod message_content;
 mod message_forward_info;
 mod message_forward_origin;
 mod message_link_info;
+mod message_scheduling_state;
 mod message_sending_state;
 mod messages;
 mod minithumbnail;
@@ -402,10 +423,12 @@ mod photo;
 mod photo_size;
 mod poll;
 mod poll_option;
+mod poll_type;
 mod profile_photo;
 mod proxies;
 mod proxy;
 mod proxy_type;
+mod public_chat_type;
 mod public_message_link;
 mod push_message_content;
 mod push_receiver_id;
@@ -419,6 +442,7 @@ mod search_messages_filter;
 mod seconds;
 mod secret_chat;
 mod secret_chat_state;
+mod send_message_options;
 mod session;
 mod sessions;
 mod shipping_option;
