@@ -75,6 +75,8 @@ pub enum PageBlock {
   Title(PageBlockTitle),
   /// A video
   Video(PageBlockVideo),
+  /// A voice note
+  VoiceNote(PageBlockVoiceNote),
 
 }
 
@@ -115,6 +117,7 @@ impl<'de> Deserialize<'de> for PageBlock {
       (pageBlockTable, Table);
       (pageBlockTitle, Title);
       (pageBlockVideo, Video);
+      (pageBlockVoiceNote, VoiceNote);
 
     )(deserializer)
   }
@@ -151,6 +154,7 @@ impl RObject for PageBlock {
       PageBlock::Table(t) => t.td_name(),
       PageBlock::Title(t) => t.td_name(),
       PageBlock::Video(t) => t.td_name(),
+      PageBlock::VoiceNote(t) => t.td_name(),
 
       _ => "-1",
     }
@@ -185,6 +189,7 @@ impl RObject for PageBlock {
       PageBlock::Table(t) => t.extra(),
       PageBlock::Title(t) => t.extra(),
       PageBlock::Video(t) => t.extra(),
+      PageBlock::VoiceNote(t) => t.extra(),
 
       _ => None,
     }
@@ -224,6 +229,7 @@ impl PageBlock {
   pub fn is_table(&self) -> bool { if let PageBlock::Table(_) = self { true } else { false } }
   pub fn is_title(&self) -> bool { if let PageBlock::Title(_) = self { true } else { false } }
   pub fn is_video(&self) -> bool { if let PageBlock::Video(_) = self { true } else { false } }
+  pub fn is_voice_note(&self) -> bool { if let PageBlock::VoiceNote(_) = self { true } else { false } }
 
   pub fn on_anchor<F: FnOnce(&PageBlockAnchor)>(&self, fnc: F) -> &Self { if let PageBlock::Anchor(t) = self { fnc(t) }; self }
   pub fn on_animation<F: FnOnce(&PageBlockAnimation)>(&self, fnc: F) -> &Self { if let PageBlock::Animation(t) = self { fnc(t) }; self }
@@ -253,6 +259,7 @@ impl PageBlock {
   pub fn on_table<F: FnOnce(&PageBlockTable)>(&self, fnc: F) -> &Self { if let PageBlock::Table(t) = self { fnc(t) }; self }
   pub fn on_title<F: FnOnce(&PageBlockTitle)>(&self, fnc: F) -> &Self { if let PageBlock::Title(t) = self { fnc(t) }; self }
   pub fn on_video<F: FnOnce(&PageBlockVideo)>(&self, fnc: F) -> &Self { if let PageBlock::Video(t) = self { fnc(t) }; self }
+  pub fn on_voice_note<F: FnOnce(&PageBlockVoiceNote)>(&self, fnc: F) -> &Self { if let PageBlock::VoiceNote(t) = self { fnc(t) }; self }
 
   pub fn as_anchor(&self) -> Option<&PageBlockAnchor> { if let PageBlock::Anchor(t) = self { return Some(t) } None }
   pub fn as_animation(&self) -> Option<&PageBlockAnimation> { if let PageBlock::Animation(t) = self { return Some(t) } None }
@@ -282,6 +289,7 @@ impl PageBlock {
   pub fn as_table(&self) -> Option<&PageBlockTable> { if let PageBlock::Table(t) = self { return Some(t) } None }
   pub fn as_title(&self) -> Option<&PageBlockTitle> { if let PageBlock::Title(t) = self { return Some(t) } None }
   pub fn as_video(&self) -> Option<&PageBlockVideo> { if let PageBlock::Video(t) = self { return Some(t) } None }
+  pub fn as_voice_note(&self) -> Option<&PageBlockVoiceNote> { if let PageBlock::VoiceNote(t) = self { return Some(t) } None }
 
 
 
@@ -341,6 +349,8 @@ impl PageBlock {
 
   pub fn video<T: AsRef<PageBlockVideo>>(t: T) -> Self { PageBlock::Video(t.as_ref().clone()) }
 
+  pub fn voice_note<T: AsRef<PageBlockVoiceNote>>(t: T) -> Self { PageBlock::VoiceNote(t.as_ref().clone()) }
+
 }
 
 impl AsRef<PageBlock> for PageBlock {
@@ -2623,3 +2633,81 @@ impl AsRef<PageBlockVideo> for RTDPageBlockVideoBuilder {
 
 
 
+
+
+
+
+/// A voice note
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct PageBlockVoiceNote {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  /// Voice note; may be null
+  voice_note: Option<VoiceNote>,
+  /// Voice note caption
+  caption: PageBlockCaption,
+  
+}
+
+impl RObject for PageBlockVoiceNote {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "pageBlockVoiceNote" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDPageBlock for PageBlockVoiceNote {}
+
+
+
+impl PageBlockVoiceNote {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDPageBlockVoiceNoteBuilder {
+    let mut inner = PageBlockVoiceNote::default();
+    inner.td_name = "pageBlockVoiceNote".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDPageBlockVoiceNoteBuilder { inner }
+  }
+
+  pub fn voice_note(&self) -> &Option<VoiceNote> { &self.voice_note }
+
+  pub fn caption(&self) -> &PageBlockCaption { &self.caption }
+
+}
+
+#[doc(hidden)]
+pub struct RTDPageBlockVoiceNoteBuilder {
+  inner: PageBlockVoiceNote
+}
+
+impl RTDPageBlockVoiceNoteBuilder {
+  pub fn build(&self) -> PageBlockVoiceNote { self.inner.clone() }
+
+   
+  pub fn voice_note<T: AsRef<VoiceNote>>(&mut self, voice_note: T) -> &mut Self {
+    self.inner.voice_note = Some(voice_note.as_ref().clone());
+    self
+  }
+
+   
+  pub fn caption<T: AsRef<PageBlockCaption>>(&mut self, caption: T) -> &mut Self {
+    self.inner.caption = caption.as_ref().clone();
+    self
+  }
+
+}
+
+impl AsRef<PageBlockVoiceNote> for PageBlockVoiceNote {
+  fn as_ref(&self) -> &PageBlockVoiceNote { self }
+}
+
+impl AsRef<PageBlockVoiceNote> for RTDPageBlockVoiceNoteBuilder {
+  fn as_ref(&self) -> &PageBlockVoiceNote { &self.inner }
+}
+
+
+
