@@ -19,11 +19,7 @@ pub struct PassportAuthorizationForm {
   id: i64,
   /// Information about the Telegram Passport elements that need to be provided to complete the form
   required_elements: Vec<PassportRequiredElement>,
-  /// Already available Telegram Passport elements
-  elements: Vec<PassportElement>,
-  /// Errors in the elements that are already available
-  errors: Vec<PassportElementError>,
-  /// URL for the privacy policy of the service; can be empty
+  /// URL for the privacy policy of the service; may be empty
   privacy_policy_url: String,
   
 }
@@ -49,10 +45,6 @@ impl PassportAuthorizationForm {
 
   pub fn required_elements(&self) -> &Vec<PassportRequiredElement> { &self.required_elements }
 
-  pub fn elements(&self) -> &Vec<PassportElement> { &self.elements }
-
-  pub fn errors(&self) -> &Vec<PassportElementError> { &self.errors }
-
   pub fn privacy_policy_url(&self) -> &String { &self.privacy_policy_url }
 
 }
@@ -78,18 +70,6 @@ impl RTDPassportAuthorizationFormBuilder {
   }
 
    
-  pub fn elements(&mut self, elements: Vec<PassportElement>) -> &mut Self {
-    self.inner.elements = elements;
-    self
-  }
-
-   
-  pub fn errors(&mut self, errors: Vec<PassportElementError>) -> &mut Self {
-    self.inner.errors = errors;
-    self
-  }
-
-   
   pub fn privacy_policy_url<T: AsRef<str>>(&mut self, privacy_policy_url: T) -> &mut Self {
     self.inner.privacy_policy_url = privacy_policy_url.as_ref().to_string();
     self
