@@ -15,28 +15,18 @@ pub struct PaymentReceipt {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// Product title
-  title: String,
-  /// Contains information about a successful payment
-  description: String,
-  /// Product photo; may be null
-  photo: Option<Photo>,
   /// Point in time (Unix timestamp) when the payment was made
   date: i64,
-  /// User identifier of the seller bot
-  seller_bot_user_id: i64,
   /// User identifier of the payment provider bot
   payments_provider_user_id: i64,
-  /// Information about the invoice
+  /// Contains information about the invoice
   invoice: Invoice,
-  /// Order information; may be null
+  /// Contains order information; may be null
   order_info: Option<OrderInfo>,
   /// Chosen shipping option; may be null
   shipping_option: Option<ShippingOption>,
-  /// Title of the saved credentials chosen by the buyer
+  /// Title of the saved credentials
   credentials_title: String,
-  /// The amount of tip chosen by the buyer in the smallest units of the currency
-  tip_amount: i64,
   
 }
 
@@ -57,16 +47,8 @@ impl PaymentReceipt {
     RTDPaymentReceiptBuilder { inner }
   }
 
-  pub fn title(&self) -> &String { &self.title }
-
-  pub fn description(&self) -> &String { &self.description }
-
-  pub fn photo(&self) -> &Option<Photo> { &self.photo }
-
   pub fn date(&self) -> i64 { self.date }
 
-  pub fn seller_bot_user_id(&self) -> i64 { self.seller_bot_user_id }
-
   pub fn payments_provider_user_id(&self) -> i64 { self.payments_provider_user_id }
 
   pub fn invoice(&self) -> &Invoice { &self.invoice }
@@ -77,8 +59,6 @@ impl PaymentReceipt {
 
   pub fn credentials_title(&self) -> &String { &self.credentials_title }
 
-  pub fn tip_amount(&self) -> i64 { self.tip_amount }
-
 }
 
 #[doc(hidden)]
@@ -90,36 +70,12 @@ impl RTDPaymentReceiptBuilder {
   pub fn build(&self) -> PaymentReceipt { self.inner.clone() }
 
    
-  pub fn title<T: AsRef<str>>(&mut self, title: T) -> &mut Self {
-    self.inner.title = title.as_ref().to_string();
-    self
-  }
-
-   
-  pub fn description<T: AsRef<str>>(&mut self, description: T) -> &mut Self {
-    self.inner.description = description.as_ref().to_string();
-    self
-  }
-
-   
-  pub fn photo<T: AsRef<Photo>>(&mut self, photo: T) -> &mut Self {
-    self.inner.photo = Some(photo.as_ref().clone());
-    self
-  }
-
-   
   pub fn date(&mut self, date: i64) -> &mut Self {
     self.inner.date = date;
     self
   }
 
    
-  pub fn seller_bot_user_id(&mut self, seller_bot_user_id: i64) -> &mut Self {
-    self.inner.seller_bot_user_id = seller_bot_user_id;
-    self
-  }
-
-   
   pub fn payments_provider_user_id(&mut self, payments_provider_user_id: i64) -> &mut Self {
     self.inner.payments_provider_user_id = payments_provider_user_id;
     self
@@ -149,12 +105,6 @@ impl RTDPaymentReceiptBuilder {
     self
   }
 
-   
-  pub fn tip_amount(&mut self, tip_amount: i64) -> &mut Self {
-    self.inner.tip_amount = tip_amount;
-    self
-  }
-
 }
 
 impl AsRef<PaymentReceipt> for PaymentReceipt {
