@@ -23,6 +23,12 @@ pub struct Poll {
   options: Vec<PollOption>,
   /// Total number of voters, participating in the poll
   total_voter_count: i64,
+  /// User identifiers of recent voters, if the poll is non-anonymous
+  recent_voter_user_ids: Vec<i64>,
+  /// True, if the poll is anonymous
+  is_anonymous: bool,
+  /// Type of the poll
+  #[serde(rename(serialize = "type", deserialize = "type"))] type_: PollType,
   /// True, if the poll is closed
   is_closed: bool,
   
@@ -53,6 +59,12 @@ impl Poll {
 
   pub fn total_voter_count(&self) -> i64 { self.total_voter_count }
 
+  pub fn recent_voter_user_ids(&self) -> &Vec<i64> { &self.recent_voter_user_ids }
+
+  pub fn is_anonymous(&self) -> bool { self.is_anonymous }
+
+  pub fn type_(&self) -> &PollType { &self.type_ }
+
   pub fn is_closed(&self) -> bool { self.is_closed }
 
 }
@@ -90,6 +102,24 @@ impl RTDPollBuilder {
   }
 
    
+  pub fn recent_voter_user_ids(&mut self, recent_voter_user_ids: Vec<i64>) -> &mut Self {
+    self.inner.recent_voter_user_ids = recent_voter_user_ids;
+    self
+  }
+
+   
+  pub fn is_anonymous(&mut self, is_anonymous: bool) -> &mut Self {
+    self.inner.is_anonymous = is_anonymous;
+    self
+  }
+
+   
+  pub fn type_<T: AsRef<PollType>>(&mut self, type_: T) -> &mut Self {
+    self.inner.type_ = type_.as_ref().clone();
+    self
+  }
+
+   
   pub fn is_closed(&mut self, is_closed: bool) -> &mut Self {
     self.inner.is_closed = is_closed;
     self
