@@ -570,7 +570,7 @@ pub struct PushMessageContentChatAddMembers {
   member_name: String,
   /// True, if the current user was added to the group
   is_current_user: bool,
-  /// True, if the user has returned to the group himself
+  /// True, if the user has returned to the group themself
   is_returned: bool,
   
 }
@@ -784,7 +784,7 @@ pub struct PushMessageContentChatDeleteMember {
   member_name: String,
   /// True, if the current user was deleted from the group
   is_current_user: bool,
-  /// True, if the user has left the group himself
+  /// True, if the user has left the group themself
   is_left: bool,
   
 }
@@ -1786,6 +1786,8 @@ pub struct PushMessageContentPoll {
   extra: Option<String>,
   /// Poll question
   question: String,
+  /// True, if the poll is regular and not in quiz mode
+  is_regular: bool,
   /// True, if the message is a pinned message with the specified content
   is_pinned: bool,
   
@@ -1813,6 +1815,8 @@ impl PushMessageContentPoll {
 
   pub fn question(&self) -> &String { &self.question }
 
+  pub fn is_regular(&self) -> bool { self.is_regular }
+
   pub fn is_pinned(&self) -> bool { self.is_pinned }
 
 }
@@ -1832,6 +1836,12 @@ impl RTDPushMessageContentPollBuilder {
   }
 
    
+  pub fn is_regular(&mut self, is_regular: bool) -> &mut Self {
+    self.inner.is_regular = is_regular;
+    self
+  }
+
+   
   pub fn is_pinned(&mut self, is_pinned: bool) -> &mut Self {
     self.inner.is_pinned = is_pinned;
     self
