@@ -37,7 +37,7 @@ pub enum RichText {
   PhoneNumber(RichTextPhoneNumber),
   /// A plain text
   Plain(RichTextPlain),
-  /// A strike-through rich text
+  /// A strikethrough rich text
   Strikethrough(RichTextStrikethrough),
   /// A subscript rich text
   Subscript(RichTextSubscript),
@@ -885,7 +885,7 @@ impl AsRef<RichTextPlain> for RTDRichTextPlainBuilder {
 
 
 
-/// A strike-through rich text
+/// A strikethrough rich text
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct RichTextStrikethrough {
   #[doc(hidden)]
@@ -1170,6 +1170,8 @@ pub struct RichTextUrl {
   text: Box<RichText>,
   /// URL
   url: String,
+  /// True, if the URL has cached instant view server-side
+  is_cached: bool,
   
 }
 
@@ -1197,6 +1199,8 @@ impl RichTextUrl {
 
   pub fn url(&self) -> &String { &self.url }
 
+  pub fn is_cached(&self) -> bool { self.is_cached }
+
 }
 
 #[doc(hidden)]
@@ -1219,6 +1223,12 @@ impl RTDRichTextUrlBuilder {
     self
   }
 
+   
+  pub fn is_cached(&mut self, is_cached: bool) -> &mut Self {
+    self.inner.is_cached = is_cached;
+    self
+  }
+
 }
 
 impl AsRef<RichTextUrl> for RichTextUrl {
