@@ -21,6 +21,10 @@ pub struct ScopeNotificationSettings {
   sound: String,
   /// True, if message content should be displayed in notifications
   show_preview: bool,
+  /// True, if notifications for incoming pinned messages will be created as for an ordinary unread message
+  disable_pinned_message_notifications: bool,
+  /// True, if notifications for messages with mentions will be created as for an ordinary unread message
+  disable_mention_notifications: bool,
   
 }
 
@@ -47,6 +51,10 @@ impl ScopeNotificationSettings {
 
   pub fn show_preview(&self) -> bool { self.show_preview }
 
+  pub fn disable_pinned_message_notifications(&self) -> bool { self.disable_pinned_message_notifications }
+
+  pub fn disable_mention_notifications(&self) -> bool { self.disable_mention_notifications }
+
 }
 
 #[doc(hidden)]
@@ -75,6 +83,18 @@ impl RTDScopeNotificationSettingsBuilder {
     self
   }
 
+   
+  pub fn disable_pinned_message_notifications(&mut self, disable_pinned_message_notifications: bool) -> &mut Self {
+    self.inner.disable_pinned_message_notifications = disable_pinned_message_notifications;
+    self
+  }
+
+   
+  pub fn disable_mention_notifications(&mut self, disable_mention_notifications: bool) -> &mut Self {
+    self.inner.disable_mention_notifications = disable_mention_notifications;
+    self
+  }
+
 }
 
 impl AsRef<ScopeNotificationSettings> for ScopeNotificationSettings {
