@@ -43,8 +43,12 @@ pub enum TextEntityType {
   Pre(TextEntityTypePre),
   /// Text that must be formatted as if inside pre, and code HTML tags
   PreCode(TextEntityTypePreCode),
+  /// A strikethrough text
+  Strikethrough(TextEntityTypeStrikethrough),
   /// A text description shown instead of a raw URL
   TextUrl(TextEntityTypeTextUrl),
+  /// An underlined text
+  Underline(TextEntityTypeUnderline),
   /// An HTTP URL
   Url(TextEntityTypeUrl),
 
@@ -71,7 +75,9 @@ impl<'de> Deserialize<'de> for TextEntityType {
       (textEntityTypePhoneNumber, PhoneNumber);
       (textEntityTypePre, Pre);
       (textEntityTypePreCode, PreCode);
+      (textEntityTypeStrikethrough, Strikethrough);
       (textEntityTypeTextUrl, TextUrl);
+      (textEntityTypeUnderline, Underline);
       (textEntityTypeUrl, Url);
 
     )(deserializer)
@@ -93,7 +99,9 @@ impl RObject for TextEntityType {
       TextEntityType::PhoneNumber(t) => t.td_name(),
       TextEntityType::Pre(t) => t.td_name(),
       TextEntityType::PreCode(t) => t.td_name(),
+      TextEntityType::Strikethrough(t) => t.td_name(),
       TextEntityType::TextUrl(t) => t.td_name(),
+      TextEntityType::Underline(t) => t.td_name(),
       TextEntityType::Url(t) => t.td_name(),
 
       _ => "-1",
@@ -113,7 +121,9 @@ impl RObject for TextEntityType {
       TextEntityType::PhoneNumber(t) => t.extra(),
       TextEntityType::Pre(t) => t.extra(),
       TextEntityType::PreCode(t) => t.extra(),
+      TextEntityType::Strikethrough(t) => t.extra(),
       TextEntityType::TextUrl(t) => t.extra(),
+      TextEntityType::Underline(t) => t.extra(),
       TextEntityType::Url(t) => t.extra(),
 
       _ => None,
@@ -138,7 +148,9 @@ impl TextEntityType {
   pub fn is_phone_number(&self) -> bool { if let TextEntityType::PhoneNumber(_) = self { true } else { false } }
   pub fn is_pre(&self) -> bool { if let TextEntityType::Pre(_) = self { true } else { false } }
   pub fn is_pre_code(&self) -> bool { if let TextEntityType::PreCode(_) = self { true } else { false } }
+  pub fn is_strikethrough(&self) -> bool { if let TextEntityType::Strikethrough(_) = self { true } else { false } }
   pub fn is_text_url(&self) -> bool { if let TextEntityType::TextUrl(_) = self { true } else { false } }
+  pub fn is_underline(&self) -> bool { if let TextEntityType::Underline(_) = self { true } else { false } }
   pub fn is_url(&self) -> bool { if let TextEntityType::Url(_) = self { true } else { false } }
 
   pub fn on_bold<F: FnOnce(&TextEntityTypeBold)>(&self, fnc: F) -> &Self { if let TextEntityType::Bold(t) = self { fnc(t) }; self }
@@ -153,7 +165,9 @@ impl TextEntityType {
   pub fn on_phone_number<F: FnOnce(&TextEntityTypePhoneNumber)>(&self, fnc: F) -> &Self { if let TextEntityType::PhoneNumber(t) = self { fnc(t) }; self }
   pub fn on_pre<F: FnOnce(&TextEntityTypePre)>(&self, fnc: F) -> &Self { if let TextEntityType::Pre(t) = self { fnc(t) }; self }
   pub fn on_pre_code<F: FnOnce(&TextEntityTypePreCode)>(&self, fnc: F) -> &Self { if let TextEntityType::PreCode(t) = self { fnc(t) }; self }
+  pub fn on_strikethrough<F: FnOnce(&TextEntityTypeStrikethrough)>(&self, fnc: F) -> &Self { if let TextEntityType::Strikethrough(t) = self { fnc(t) }; self }
   pub fn on_text_url<F: FnOnce(&TextEntityTypeTextUrl)>(&self, fnc: F) -> &Self { if let TextEntityType::TextUrl(t) = self { fnc(t) }; self }
+  pub fn on_underline<F: FnOnce(&TextEntityTypeUnderline)>(&self, fnc: F) -> &Self { if let TextEntityType::Underline(t) = self { fnc(t) }; self }
   pub fn on_url<F: FnOnce(&TextEntityTypeUrl)>(&self, fnc: F) -> &Self { if let TextEntityType::Url(t) = self { fnc(t) }; self }
 
   pub fn as_bold(&self) -> Option<&TextEntityTypeBold> { if let TextEntityType::Bold(t) = self { return Some(t) } None }
@@ -168,7 +182,9 @@ impl TextEntityType {
   pub fn as_phone_number(&self) -> Option<&TextEntityTypePhoneNumber> { if let TextEntityType::PhoneNumber(t) = self { return Some(t) } None }
   pub fn as_pre(&self) -> Option<&TextEntityTypePre> { if let TextEntityType::Pre(t) = self { return Some(t) } None }
   pub fn as_pre_code(&self) -> Option<&TextEntityTypePreCode> { if let TextEntityType::PreCode(t) = self { return Some(t) } None }
+  pub fn as_strikethrough(&self) -> Option<&TextEntityTypeStrikethrough> { if let TextEntityType::Strikethrough(t) = self { return Some(t) } None }
   pub fn as_text_url(&self) -> Option<&TextEntityTypeTextUrl> { if let TextEntityType::TextUrl(t) = self { return Some(t) } None }
+  pub fn as_underline(&self) -> Option<&TextEntityTypeUnderline> { if let TextEntityType::Underline(t) = self { return Some(t) } None }
   pub fn as_url(&self) -> Option<&TextEntityTypeUrl> { if let TextEntityType::Url(t) = self { return Some(t) } None }
 
 
@@ -197,8 +213,12 @@ impl TextEntityType {
 
   pub fn pre_code<T: AsRef<TextEntityTypePreCode>>(t: T) -> Self { TextEntityType::PreCode(t.as_ref().clone()) }
 
+  pub fn strikethrough<T: AsRef<TextEntityTypeStrikethrough>>(t: T) -> Self { TextEntityType::Strikethrough(t.as_ref().clone()) }
+
   pub fn text_url<T: AsRef<TextEntityTypeTextUrl>>(t: T) -> Self { TextEntityType::TextUrl(t.as_ref().clone()) }
 
+  pub fn underline<T: AsRef<TextEntityTypeUnderline>>(t: T) -> Self { TextEntityType::Underline(t.as_ref().clone()) }
+
   pub fn url<T: AsRef<TextEntityTypeUrl>>(t: T) -> Self { TextEntityType::Url(t.as_ref().clone()) }
 
 }
@@ -929,6 +949,64 @@ impl AsRef<TextEntityTypePreCode> for RTDTextEntityTypePreCodeBuilder {
 
 
 
+/// A strikethrough text
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct TextEntityTypeStrikethrough {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  
+}
+
+impl RObject for TextEntityTypeStrikethrough {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "textEntityTypeStrikethrough" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDTextEntityType for TextEntityTypeStrikethrough {}
+
+
+
+impl TextEntityTypeStrikethrough {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDTextEntityTypeStrikethroughBuilder {
+    let mut inner = TextEntityTypeStrikethrough::default();
+    inner.td_name = "textEntityTypeStrikethrough".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDTextEntityTypeStrikethroughBuilder { inner }
+  }
+
+}
+
+#[doc(hidden)]
+pub struct RTDTextEntityTypeStrikethroughBuilder {
+  inner: TextEntityTypeStrikethrough
+}
+
+impl RTDTextEntityTypeStrikethroughBuilder {
+  pub fn build(&self) -> TextEntityTypeStrikethrough { self.inner.clone() }
+
+}
+
+impl AsRef<TextEntityTypeStrikethrough> for TextEntityTypeStrikethrough {
+  fn as_ref(&self) -> &TextEntityTypeStrikethrough { self }
+}
+
+impl AsRef<TextEntityTypeStrikethrough> for RTDTextEntityTypeStrikethroughBuilder {
+  fn as_ref(&self) -> &TextEntityTypeStrikethrough { &self.inner }
+}
+
+
+
+
+
+
+
 /// A text description shown instead of a raw URL
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct TextEntityTypeTextUrl {
@@ -997,6 +1075,64 @@ impl AsRef<TextEntityTypeTextUrl> for RTDTextEntityTypeTextUrlBuilder {
 
 
 
+/// An underlined text
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct TextEntityTypeUnderline {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  
+}
+
+impl RObject for TextEntityTypeUnderline {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "textEntityTypeUnderline" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDTextEntityType for TextEntityTypeUnderline {}
+
+
+
+impl TextEntityTypeUnderline {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDTextEntityTypeUnderlineBuilder {
+    let mut inner = TextEntityTypeUnderline::default();
+    inner.td_name = "textEntityTypeUnderline".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDTextEntityTypeUnderlineBuilder { inner }
+  }
+
+}
+
+#[doc(hidden)]
+pub struct RTDTextEntityTypeUnderlineBuilder {
+  inner: TextEntityTypeUnderline
+}
+
+impl RTDTextEntityTypeUnderlineBuilder {
+  pub fn build(&self) -> TextEntityTypeUnderline { self.inner.clone() }
+
+}
+
+impl AsRef<TextEntityTypeUnderline> for TextEntityTypeUnderline {
+  fn as_ref(&self) -> &TextEntityTypeUnderline { self }
+}
+
+impl AsRef<TextEntityTypeUnderline> for RTDTextEntityTypeUnderlineBuilder {
+  fn as_ref(&self) -> &TextEntityTypeUnderline { &self.inner }
+}
+
+
+
+
+
+
+
 /// An HTTP URL
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct TextEntityTypeUrl {
