@@ -19,6 +19,8 @@ pub struct VideoNote {
   duration: i64,
   /// Video width and height; as defined by the sender
   length: i64,
+  /// Video minithumbnail; may be null
+  minithumbnail: Option<Minithumbnail>,
   /// Video thumbnail; as defined by the sender; may be null
   thumbnail: Option<PhotoSize>,
   /// File containing the video
@@ -47,6 +49,8 @@ impl VideoNote {
 
   pub fn length(&self) -> i64 { self.length }
 
+  pub fn minithumbnail(&self) -> &Option<Minithumbnail> { &self.minithumbnail }
+
   pub fn thumbnail(&self) -> &Option<PhotoSize> { &self.thumbnail }
 
   pub fn video(&self) -> &File { &self.video }
@@ -74,6 +78,12 @@ impl RTDVideoNoteBuilder {
   }
 
    
+  pub fn minithumbnail<T: AsRef<Minithumbnail>>(&mut self, minithumbnail: T) -> &mut Self {
+    self.inner.minithumbnail = Some(minithumbnail.as_ref().clone());
+    self
+  }
+
+   
   pub fn thumbnail<T: AsRef<PhotoSize>>(&mut self, thumbnail: T) -> &mut Self {
     self.inner.thumbnail = Some(thumbnail.as_ref().clone());
     self
